<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       www.redefiningtheweb.com
 * @since      1.0.0
 *
 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor
 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/admin
 */
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor
 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/admin
 * @author     RedefinignTheWeb <support@redefiningtheweb.com>
 */
class Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Admin {
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwwpge_plugin_name    The ID of this plugin.
	 */
	private $rtwwpge_plugin_name;
	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwwpge_version    The current version of this plugin.
	 */
	private $rtwwpge_version;
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $rtwwpge_plugin_name       The name of this plugin.
	 * @param      string    $rtwwpge_version    The version of this plugin.
	 */
	public function __construct( $rtwwpge_plugin_name, $rtwwpge_version ) {
		$this->rtwwpge_plugin_name = $rtwwpge_plugin_name;
		$this->rtwwpge_version = $rtwwpge_version;
	}
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function rtwwpge_enqueue_styles() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwwpge_run() function
		 * defined in Wordpress_Pdf_Generator_For_Elementor_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wordpress_Pdf_Generator_For_Elementor_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( $this->rtwwpge_plugin_name, plugin_dir_url( __FILE__ ) . 'css/rtwwpge-wordpress-pdf-generator-for-elementor-admin.css', array(), $this->rtwwpge_version, 'all' );
		wp_enqueue_style('thickbox');
		wp_enqueue_style( 'wp-color-picker');
	}
	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function rtwwpge_enqueue_scripts() {
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwwpge_run() function
		 * defined in Wordpress_Pdf_Generator_For_Elementor_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wordpress_Pdf_Generator_For_Elementor_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_register_script( $this->rtwwpge_plugin_name, plugin_dir_url( __FILE__ ) . 'js/rtwwpge-wordpress-pdf-generator-for-elementor-admin.js', array( 'jquery', 'wp-color-picker' ), $this->rtwwpge_version, false );
        wp_enqueue_script( 'media-upload' );
		wp_enqueue_script( 'thickbox' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'blockUI', plugin_dir_url( __FILE__ ) . 'js/jquery-blockui/jquery.blockUI.min.js', array( 'jquery' ), $this->rtwwpge_version, false );

		wp_enqueue_script( $this->rtwwpge_plugin_name, plugin_dir_url( __FILE__ ) . 'js/rtwwpge-wordpress-pdf-generator-for-elementor-admin.js', array( 'jquery' ), $this->rtwwpge_version, false );

		wp_enqueue_script( 'rtwwpge_global', plugin_dir_url( __FILE__ ) . 'js/rtwwpge-wordpress-pdf-generator-for-elementor-global.js', array( 'jquery' ), $this->rtwwpge_version, false );

		$rtwwpge_ajax_nonce = wp_create_nonce( "rtwwpge-ajax-security-string" );
		wp_localize_script( $this->rtwwpge_plugin_name, 'rtwwpge_obj', array( 'ajax_url' => esc_url( admin_url('admin-ajax.php') ), 'rtwwpge_nonce' => $rtwwpge_ajax_nonce ) );

	}
	/**
	 * Delete pdf when post updated.
	 *
	 * @since    1.0.1
	 */
	function rtwwpge_pdf_delete( $rtwwpge_post_id )
	{
		global $post;

		if ($post) {
			if( file_exists( RTWWPGE_PDF_DIR . '/' .$rtwwpge_post_id.'.pdf' ) )
			{
				unlink(RTWWPGE_PDF_DIR . '/' .$rtwwpge_post_id.'.pdf');
			}
			if( file_exists( RTWWPGE_PDF_DIR . '/' .$post->post_name.'.pdf' ) )
			{
				unlink(RTWWPGE_PDF_DIR . '/' . $post->post_name.'.pdf');
			}
		}
	}
	
	/**
	 * This Function is used add menu setting
	 *
	 * @since    1.0.0
	 * @name rtwwpge_add_menu_page
	 */
	public function rtwwpge_add_menu_page()
	{   
			add_menu_page(esc_html__('PDFMentor Pro Setting','rtwwpge-wordpress-pdf-generator-for-elementor'),esc_html__('PDFMentor Pro','rtwwpge-wordpress-pdf-generator-for-elementor'),'manage_options','rtwwpge',array($this,'rtwwpge_add_menu_page_html'),RTWWPGE_URL.'assets/icon.png');
	}
	/**
	 * This Function is used add html for menu setting
	 *
	 * @since    1.0.0
	 * @name rtwwpge_add_menu_page_html
	 */
	public function rtwwpge_add_menu_page_html()
	{
		include(RTWWPGE_DIR.'admin/partials/rtwwpge-wordpress-pdf-generator-for-elementor-admin-display.php');
	}
	/**
	 * This Function is used save admin settings
	 *
	 * @since    1.0.0
	 * @name rtwwpge_save_admin_setting
	 */
	public function rtwwpge_save_admin_setting()
	{
			if( isset( $_POST['rtwwpge_pdf_submit'] ) )
			{
				$rtwwpge_pdf_dir = RTWWPGE_PDF_DIR;
				array_map('unlink', glob("$rtwwpge_pdf_dir/*.*"));
			}
			register_setting('rtwwpge_header_setting','rtwwpge_header_setting_opt');
			register_setting('rtwwpge_footer_setting','rtwwpge_footer_setting_opt');
			register_setting('rtwwpge_basic_setting','rtwwpge_basic_setting_opt');
			register_setting('rtwwpge_css_setting','rtwwpge_css_setting_opt');
			register_setting('rtwwpge_watermark_setting','rtwwpge_watermark_setting_opt');
			register_setting('rtwwpge_singleprdt_setting','rtwwpge_singleprdt_setting_opt');
	}

	/**
	 * This Function is used to purge PDF cache from admin toolbar
	 *
	 * @since    2.2.0
	 * @name rtwwpge_purge_cache_admin_bar
	 */
	public function rtwwpge_purge_cache_admin_bar($rtwwpge_admin_bar) {
		$args = array(
			'id' => 'rtwwpge-purge-cache',
			'title' => '<span class="ab-icon"></span><span class="ab-label">'.esc_html__('Purge PDF Cache', 'rtwwpge-wordpress-pdf-generator-for-elementor').'</span>'
		);
		$rtwwpge_admin_bar->add_node($args);
	}

	/**
	 * Purge all PDF when purge cache button clicked.
	 *
	 * @since    2.2.0
	 */
	public function rtwwpge_pdf_purge_all()
	{
		$rtwwpge_pdf_dir = RTWWPGE_PDF_DIR;
		array_map('unlink', glob("$rtwwpge_pdf_dir/*.*"));
		echo json_encode( array('status' => true, 'message' => 'cache cleared successfully') );
		wp_die();
	}

	/**
	* This function verifies purchase code
	* @since 2.2.0
	*/
	public function rtwwpge_verify_purchase_code_callback()
	{
		if (!wp_verify_nonce($_POST['security_check'], 'rtwwpge-ajax-security-string')){
			return;
		}

		$rtwwpge_purchase_code = sanitize_text_field( $_POST['purchase_code'] );
		$rtwwpge_user_data     = get_user_meta( wp_get_current_user()->data->ID );
		$rtwwpge_site_data     = explode( '://', get_site_url());
		$rtwwpge_site_domain 	= $rtwwpge_site_data[1];
		$rtwwpge_admin_email 	= get_option('admin_email');
		$wp_get_current_user 	= wp_get_current_user();
		$rtwwpge_admin_name 	= $rtwwpge_user_data['first_name'][0].' '.$rtwwpge_user_data['last_name'][0];
		$rtwwpge_plugin_name 	= 'PDFMentor Pro - WordPress PDF Generator for Elementor';
		$plugin_text_domain 	= 'rtwwpge-wordpress-pdf-generator-for-elementor';
		
		$rtwwpge_post_array = array(
			'site_domain' => $rtwwpge_site_domain,
			'admin_email' => $rtwwpge_admin_email,
			'admin_name' => $rtwwpge_admin_name,
			'plugin_name' => $rtwwpge_plugin_name,
			'text_domain' => $plugin_text_domain,
			'purchase_code' => $rtwwpge_purchase_code 
		);

		$args = array(
		    'method' => 'POST',
		    'headers'  => array( 'Content-type: application/x-www-form-urlencoded' ),
		    'sslverify' => false,
		    'body' => $rtwwpge_post_array
		);

		$response = wp_remote_post( 'https://demo.redefiningtheweb.com/license-verification/license-verification.php', $args ) ;

		if(is_wp_error($response))
		{
			$rtwwpge_result = array( 'status' => false,
			'message' => $response->get_error_message() );
			echo json_encode( $rtwwpge_result );
			die;
		}

		$response_body = json_decode( $response['body'] );
		$response_status = $response_body->result;
		$response_message = $response_body->message;

		if( $response_status ) {
			$rtwwpge_update_array = array( 'purchase_code' => $rtwwpge_purchase_code, 'status' => true );
			update_option( 'rtwwpge_verification_done', $rtwwpge_update_array );
			$rtwwpge_result = array( 'status' => true, 'message' => $response_message );
			echo json_encode( $rtwwpge_result );
		}
		else {
			$rtwwpge_result = array( 'status' => false, 'message' => $response_message );
			echo json_encode( $rtwwpge_result );
		}
		wp_die();
	}
	
	/**
	* This function to remove purchase code
	* @since 2.2.0
	*/
	public function rtwwpge_delete_purchase_code()
	{
		$rtwwpge_site_url 		= get_site_url();
		$rtwwpge_admin_email 	= get_option('admin_email');
		$wp_get_current_user 	= get_user_meta( get_current_user_id() );

		if( is_array($wp_get_current_user) && !empty( $wp_get_current_user ) )
		{
			if( isset( $wp_get_current_user['first_name'][0]))
			{
				$rtwwpge_admin_name = $wp_get_current_user['first_name'][0] . ' '. $wp_get_current_user['last_name'][0];
			}
		}
		else
		{
			$wp_get_current_user 	= wp_get_current_user();
			$rtwwpge_admin_name 	= $wp_get_current_user->data->user_nicename;
		}

		$rtwwpge_plugin_name 	= 'PDFMentor Pro - WordPress PDF Generator for Elementor';
		$plugin_text_domain 	= 'rtwwpge-wordpress-pdf-generator-for-elementor';
		$rtwwpge_site_domain 	= preg_replace( "(^https?://)", "", $rtwwpge_site_url );
		$rtwwpge_purchase_code = get_option( 'rtwwpge_verification_done', array() );

		$rtwwpge_post_array = array(
			'site_domain' => $rtwwpge_site_domain,
			'admin_email' => $rtwwpge_admin_email,
			'admin_name' => $rtwwpge_admin_name,
			'plugin_name' => $rtwwpge_plugin_name,
			'text_domain' => $plugin_text_domain,
			'purchase_code' => $rtwwpge_purchase_code['purchase_code'],
			'plugin_id' => 28376760
		);

		$args = array(
			'method' => 'POST',
			'headers'  => array( 'Content-type: application/x-www-form-urlencoded' ),
			'sslverify' => false,
			'body' => $rtwwpge_post_array
		);

		$response = wp_remote_post( 'https://demo.redefiningtheweb.com/license-verification/license-remove.php', $args );
		
		delete_option('rtwwpge_verification_done');
		wp_redirect( esc_url( admin_url( 'admin.php?page=rtwwpge' ) ) );
		exit;
	}

	/**
	* This function display the admin notice when purchase code not done
	* @since 2.2.0
	*/
	public function rtwwpge_show_notices()
	{
		$rtwwpge_purchase_code_details = get_option( 'rtwwpge_verification_done', array() );
		
		if( empty($rtwwpge_purchase_code_details) && (!isset($rtwwpge_purchase_code_details['status']) || $rtwwpge_purchase_code_details['status'] == false) && (!isset($rtwwpge_purchase_code_details['purchase_code']) || $rtwwpge_purchase_code_details['purchase_code'] == '') && ( !isset($_GET['page']) || $_GET['page'] != 'rtwwpge' ) )
		{
			?>
				<div class="notice notice-error is-dismissible">
					<p>
						<?php esc_html_e( 'Please Enter Your Purchase Code To Activate "PDFMentor Pro - WordPress PDF Generator for Elementor" ', 'rtwwpge-wordpress-pdf-generator-for-elementor' ); ?>
						<strong><a href="<?php echo esc_url( home_url()."/wp-admin/admin.php?page=rtwwpge" ); ?>"><?php esc_html_e('Verify Purchase Code', 'rtwwpge-wordpress-pdf-generator-for-elementor') ?></a></strong>
					</p>
				</div>
			<?php
		}
	}
}