<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       www.redefiningtheweb.com
 * @since      1.0.0
 *
 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor
 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor
 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/includes
 * @author     RedefinignTheWeb <support@redefiningtheweb.com>
 */

class Rtwwpge_Wordpress_Pdf_Generator_For_Elementor {


	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Loader    $rtwwpge_loader    Maintains and registers all hooks for the plugin.
	 */
	protected $rtwwpge_loader;


	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $rtwwpge_plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $rtwwpge_plugin_name;


	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $rtwwpge_version    The current version of the plugin.
	 */
	protected $rtwwpge_version;


	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'RTWWPGE_WORDPRESS_PDF_GENERATOR_FOR_ELEMENTOR_VERSION' ) ) {
			$this->rtwwpge_version = RTWWPGE_WORDPRESS_PDF_GENERATOR_FOR_ELEMENTOR_VERSION;
		} else {
			$this->rtwwpge_version = '1.0.0';
		}
		$this->rtwwpge_plugin_name = 'rtwwpge-wordpress-pdf-generator-for-elementor';
		$this->rtwwpge_load_dependencies();
		$this->rtwwpge_set_locale();
		$this->rtwwpge_define_admin_hooks();
		$this->rtwwpge_define_public_hooks();
	}


	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Loader. Orchestrates the hooks of the plugin.
	 * - Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_i18n. Defines internationalization functionality.
	 * - Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Admin. Defines all hooks for the admin area.
	 * - Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function rtwwpge_load_dependencies() {


		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/rtwwpge-class-wordpress-pdf-generator-for-elementor-loader.php';
		
		
		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/rtwwpge-class-wordpress-pdf-generator-for-elementor-i18n.php';
		
		
		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/rtwwpge-class-wordpress-pdf-generator-for-elementor-admin.php';
		
		
		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/rtwwpge-class-wordpress-pdf-generator-for-elementor-public.php';
		$this->rtwwpge_loader = new Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Loader();
	}


	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function rtwwpge_set_locale() {
		$rtwwpge_plugin_i18n = new Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_i18n();
		$this->rtwwpge_loader->rtwwpge_add_action( 'plugins_loaded', $rtwwpge_plugin_i18n, 'rtwwpge_load_plugin_textdomain' );
	}


	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function rtwwpge_define_admin_hooks() {
		$rtwwpge_plugin_admin = new Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Admin( $this->rtwwpge_get_plugin_name(), $this->rtwwpge_get_version() );
		$this->rtwwpge_loader->rtwwpge_add_action( 'admin_enqueue_scripts', $rtwwpge_plugin_admin, 'rtwwpge_enqueue_styles' );
		$this->rtwwpge_loader->rtwwpge_add_action( 'admin_enqueue_scripts', $rtwwpge_plugin_admin, 'rtwwpge_enqueue_scripts' );
		$this->rtwwpge_loader->rtwwpge_add_action('admin_menu', $rtwwpge_plugin_admin, 'rtwwpge_add_menu_page');
		$this->rtwwpge_loader->rtwwpge_add_action('wp_ajax_rtwwpge_verify_purchase_code', $rtwwpge_plugin_admin, 'rtwwpge_verify_purchase_code_callback');

		$rtwwpge_purchase_code_details = get_option( 'rtwwpge_verification_done', array() );

		if (!empty($rtwwpge_purchase_code_details) && is_array($rtwwpge_purchase_code_details) && isset($rtwwpge_purchase_code_details['status']) && $rtwwpge_purchase_code_details['status'] == true && isset($rtwwpge_purchase_code_details['purchase_code']) && $rtwwpge_purchase_code_details['purchase_code'] != '' )
		{
			$this->rtwwpge_loader->rtwwpge_add_action('admin_init', $rtwwpge_plugin_admin, 'rtwwpge_save_admin_setting');
			$this->rtwwpge_loader->rtwwpge_add_action('save_post', $rtwwpge_plugin_admin, 'rtwwpge_pdf_delete');
			$this->rtwwpge_loader->rtwwpge_add_action('wp_ajax_rtwwpge_purge_action', $rtwwpge_plugin_admin, 'rtwwpge_pdf_purge_all');
			$this->rtwwpge_loader->rtwwpge_add_action('admin_bar_menu', $rtwwpge_plugin_admin, 'rtwwpge_purge_cache_admin_bar', 999);

			if(isset($_GET['rtwwpge_action']) && $_GET['rtwwpge_action'] == 'delete_purchase_code')	{
				$this->rtwwpge_loader->rtwwpge_add_action( 'admin_init', $rtwwpge_plugin_admin, 'rtwwpge_delete_purchase_code' );
			}
		}
		
		if( empty($rtwwpge_purchase_code_details) && (!isset($rtwwpge_purchase_code_details['status']) || $rtwwpge_purchase_code_details['status'] == false) && (!isset($rtwwpge_purchase_code_details['purchase_code']) || $rtwwpge_purchase_code_details['purchase_code'] == '') && ( !isset($_GET['page']) || $_GET['page'] != 'rtwwpge' ) )
		{
			$this->rtwwpge_loader->rtwwpge_add_action('admin_notices', $rtwwpge_plugin_admin, 'rtwwpge_show_notices');
		}
	}


	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function rtwwpge_define_public_hooks() {
		$rtwwpge_plugin_public = new Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Public( $this->rtwwpge_get_plugin_name(), $this->rtwwpge_get_version() );
		$this->rtwwpge_loader->rtwwpge_add_action( 'wp_enqueue_scripts', $rtwwpge_plugin_public, 'rtwwpge_enqueue_styles' );
		$this->rtwwpge_loader->rtwwpge_add_action( 'wp_enqueue_scripts', $rtwwpge_plugin_public, 'rtwwpge_enqueue_scripts' );
		if( isset( $_GET['rtwwpge_generate_pdf'] ) && $_GET['rtwwpge_generate_pdf'] == true )
		{
			$this->rtwwpge_loader->rtwwpge_add_filter('elementor/frontend/the_content', $rtwwpge_plugin_public, 'rtwwpge_convert_to_pdf', 10000000);
			$this->rtwwpge_loader->rtwwpge_add_action('init', $rtwwpge_plugin_public, 'rtwwpge_json_envor');
		}
		$this->rtwwpge_loader->rtwwpge_add_action( 'init', $rtwwpge_plugin_public, 'rtwwpge_dwnld_pdf' );
		$this->rtwwpge_loader->rtwwpge_add_action('elementor/widgets/widgets_registered', $rtwwpge_plugin_public, 'rtwwpge_add_new_elements');
		$this->rtwwpge_loader->rtwwpge_add_action('woocommerce_grouped_price_html', $rtwwpge_plugin_public, 'rtwwpge_grouped_prdt_price','',1);
		$this->rtwwpge_loader->rtwwpge_add_action('woocommerce_variable_price_html', $rtwwpge_plugin_public, 'rtwwpge_variable_prdt_price','',2);
	}


	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function rtwwpge_run() {
		$this->rtwwpge_loader->rtwwpge_run();
	}


	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function rtwwpge_get_plugin_name() {
		return $this->rtwwpge_plugin_name;
	}


	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Wordpress_Pdf_Generator_For_Elementor_Loader    Orchestrates the hooks of the plugin.
	 */
	public function rtwwpge_get_loader() {
		return $this->rtwwpge_loader;
	}

	
	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function rtwwpge_get_version() {
		return $this->rtwwpge_version;
	}
}