<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              www.redefiningtheweb.com
 * @since             1.0.0
 * @package           Rtwwpge_Wordpress_Pdf_Generator_For_Elementor
 *
 * @wordpress-plugin
 * Plugin Name:       PDFMentor Pro - WordPress PDF Generator for Elementor
 * Plugin URI:        https://www.persianscript.ir
 * Description:       Unlock the full power of Pro, PDFMentor Pro is a PDF generator addon of Elementor Website Builder for WordPress sites, which allows creating PDFs of posts, pages, etc.
 * Version:           2.2.0
 * Author:            پرشین اسکریپت
 * Author URI:        https://www.persianscript.ir
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       rtwwpge-wordpress-pdf-generator-for-elementor
 * Domain Path:       /languages
 * Elementor tested up to: 3.5.6
 */


// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

function rtwwpge_check_run_allows()
{
	$rtwwpge_pro_status = true;
	if( function_exists('is_multisite') && is_multisite() )
	{
		include_once(ABSPATH. 'wp-admin/includes/plugin.php');
		if( !is_plugin_active('pdf-generator-addon-for-elementor-page-builder/pdf-generator-addon-for-elementor-page-builder.php') || !is_plugin_active('elementor/elementor.php') )
		{
			$rtwwpge_pro_status = false;
		}
		else {
			$rtwwpge_pro_status = true;
		}
	}
	else
	{
		if( !in_array('pdf-generator-addon-for-elementor-page-builder/pdf-generator-addon-for-elementor-page-builder.php', apply_filters( 'active_plugins', get_option('active_plugins') )) )
		{
			$rtwwpge_pro_status = false;
		}

		if( !in_array('elementor/elementor.php', apply_filters( 'active_plugins', get_option('active_plugins') )) )
		{
			$rtwwpge_pro_status = false;
		}
	}

	return $rtwwpge_pro_status;
}

if (rtwwpge_check_run_allows() === true)
{
	/**
	 * Define Plugin Constant
	 * @name rtwwpge_define_constant
	 *
	 * @since    1.0.0
	 */
	
	//Define Plugin Constant
	function rtwwpge_define_constant()
	{
		if( !defined('RTWWPGE_PDF_DIR') )
		{
			define ('RTWWPGE_PDF_DIR', WP_CONTENT_DIR .'/uploads/rtwwpge_pdf');
		}
		if( !defined('RTWWPGE_DIR') )
		{
		    define('RTWWPGE_DIR', plugin_dir_path( __FILE__ ) );
		}
		if( !defined('RTWWPGE_URL') )
		{
			define('RTWWPGE_URL', plugin_dir_url( __FILE__ ) );
		}
		if( !defined('RTWWPGE_HOME') )
		{
			 define('RTWWPGE_HOME', home_url() );
		}
	}
	//Plugin Constant end



	/**
	 * Currently plugin version.
	 * Start at version 1.0.0 and use SemVer - https://semver.org
	 * Rename this for your plugin and update it as you release new versions.
	 */
	define( 'RTWWPGE_WORDPRESS_PDF_GENERATOR_FOR_ELEMENTOR_VERSION', '2.2.0' );


	/**
	 * The code that runs during plugin activation.
	 * This action is documented in includes/rtwwpge-class-wordpress-pdf-generator-for-elementor-activator.php
	 */
	function rtwwpge_activate_wordpress_pdf_generator_for_elementor() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/rtwwpge-class-wordpress-pdf-generator-for-elementor-activator.php';
		Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Activator::rtwwpge_activate();
	}



	/**
	 * The code that runs during plugin deactivation.
	 * This action is documented in includes/rtwwpge-class-wordpress-pdf-generator-for-elementor-deactivator.php
	 */
	function rtwwpge_deactivate_wordpress_pdf_generator_for_elementor() {
		require_once plugin_dir_path( __FILE__ ) . 'includes/rtwwpge-class-wordpress-pdf-generator-for-elementor-deactivator.php';
		Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Deactivator::rtwwpge_deactivate();
	}


	register_activation_hook( __FILE__, 'rtwwpge_activate_wordpress_pdf_generator_for_elementor' );
	register_deactivation_hook( __FILE__, 'rtwwpge_deactivate_wordpress_pdf_generator_for_elementor' );


	/**
	 * The core plugin class that is used to define internationalization,
	 * admin-specific hooks, and public-facing site hooks.
	 */
	require plugin_dir_path( __FILE__ ) . 'includes/rtwwpge-class-wordpress-pdf-generator-for-elementor.php';



	/**
	 * Begins execution of the plugin.
	 *
	 * Since everything within the plugin is registered via hooks,
	 * then kicking off the plugin from this point in the file does
	 * not affect the page life cycle.
	 *
	 * @since    1.0.0
	 */
	function rtwwpge_run_wordpress_pdf_generator_for_elementor() {
		$plugin_name = new Rtwwpge_Wordpress_Pdf_Generator_For_Elementor();
		$plugin_name->rtwwpge_run();
	}
	rtwwpge_define_constant();
	rtwwpge_run_wordpress_pdf_generator_for_elementor();
}
else
{
	function rtwwpge_error_notice()
	{
		?>
		<div class="error notice is-dismissible">
			<p id="rtwwpge_act_error">
				<?php esc_html_e( ' Please install and activate both plugins ', 'rtwwpge-wordpress-pdf-generator-for-elementor' ); ?>
				
				<strong><a target="_blank" href="<?php echo esc_url( "https://wordpress.org/plugins/pdf-generator-addon-for-elementor-page-builder/" ); ?>"><?php esc_html_e('"PDF Generator Addon for Elementor Page Builder"', 'rtwwpge-wordpress-pdf-generator-for-elementor') ?></a></strong>

				<?php esc_html_e( ' and ', 'rtwwpge-wordpress-pdf-generator-for-elementor' ); ?>
				
				<strong><a target="_blank" href="<?php echo esc_url( "https://wordpress.org/plugins/elementor/" ); ?>"><?php esc_html_e('"Elementor"', 'rtwwpge-wordpress-pdf-generator-for-elementor') ?></a></strong>
				
				<?php esc_html_e( ' to activate PDFMentor Pro.', 'rtwwpge-wordpress-pdf-generator-for-elementor' ); ?>

			</p>
		</div>
		<style type="text/css">
			#message {
				display: none;
			}
			#rtwwpge_act_error a {
				text-decoration: none;
			}
		</style>
		<?php
	}

		/**
	* Deactivate Plugin if Elementor not active
	* @since 1.0.0
	*/
	function rtwwpge_deactivate_wordpress_pdf_generator_for_elementor()
	{
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		deactivate_plugins( plugin_basename( __FILE__ ) );
		add_action('admin_notices', 'rtwwpge_error_notice');
	}
	add_action( 'admin_init', 'rtwwpge_deactivate_wordpress_pdf_generator_for_elementor' );
}