<?php

/**
 * The public-specific functionality of the plugin.
 *
 * @link       www.redefiningtheweb.com
 * @since      1.0.0
 *
 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor
 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/public
 */

/**
 * The public-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-specific stylesheet and JavaScript.
 *
 * @package    Rtwwpge_Wordpress_Pdf_Generator_For_Elementor
 * @subpackage Rtwwpge_Wordpress_Pdf_Generator_For_Elementor/public
 * @author     RedefinignTheWeb <support@redefiningtheweb.com>
 */
class Rtwwpge_Wordpress_Pdf_Generator_For_Elementor_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwwpge_plugin_name    The ID of this plugin.
	 */
	private $rtwwpge_plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $rtwwpge_version    The current version of this plugin.
	 */
	private $rtwwpge_version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $rtwwpge_plugin_name       The name of this plugin.
	 * @param      string    $rtwwpge_version    The version of this plugin.
	 */
	private $rtwwpge_post_css_file_path;
	public function __construct( $rtwwpge_plugin_name, $rtwwpge_version ) {

		$this->rtwwpge_plugin_name = $rtwwpge_plugin_name;
		$this->rtwwpge_version = $rtwwpge_version;
		$rtwwpge_basic_stng = get_option('rtwwpge_basic_setting_opt');
		if( !$rtwwpge_basic_stng )
		{
			$rtwwpge_basic_stng = array();
		}
		$rtwwpge_css_stng = get_option('rtwwpge_css_setting_opt');
		if( !$rtwwpge_css_stng )
		{
			$rtwwpge_css_stng = array();
		}
		$rtwwpge_header_stng = get_option('rtwwpge_header_setting_opt');
		if( !$rtwwpge_header_stng )
		{
			$rtwwpge_header_stng = array();
		}
		$rtwwpge_footer_stng = get_option('rtwwpge_footer_setting_opt');
		if( !$rtwwpge_footer_stng )
		{
			$rtwwpge_footer_stng = array();
		}
		$rtwwpge_watermark_stng = get_option('rtwwpge_watermark_setting_opt');
		if( !$rtwwpge_watermark_stng )
		{
			$rtwwpge_watermark_stng = array();
		}
		$rtwwpge_singleprdt_stng = get_option('rtwwpge_singleprdt_setting_opt');
		if( !$rtwwpge_singleprdt_stng )
		{
			$rtwwpge_singleprdt_stng = array();
		}
		$this->rtwwpge_stng = array_merge($rtwwpge_basic_stng, $rtwwpge_css_stng, $rtwwpge_header_stng, $rtwwpge_footer_stng, $rtwwpge_watermark_stng, $rtwwpge_singleprdt_stng);
		add_action('elementor/element/parse_css', array($this, 'rtwwpge_post_css_file_path'));
	}

	function rtwwpge_post_css_file_path($rtwwpge_css_file)
	{
		$this->rtwwpge_post_css_file_path = $rtwwpge_css_file;
    }

	/**
	 * Register the stylesheets for the public area.
	 *
	 * @since    1.0.0
	 */
	public function rtwwpge_enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwwpge_run() function
		 * defined in Wordpress_Pdf_Generator_For_Elementor_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wordpress_Pdf_Generator_For_Elementor_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->rtwwpge_plugin_name, plugin_dir_url( __FILE__ ) . 'css/rtwwpge-wordpress-pdf-generator-for-elementor-public.css', array(), $this->rtwwpge_version, 'all' );
        
	}

	/**
	 * Register the JavaScript for the public area.
	 *
	 * @since    1.0.0
	 */
	public function rtwwpge_enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the rtwwpge_run() function
		 * defined in Wordpress_Pdf_Generator_For_Elementor_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wordpress_Pdf_Generator_For_Elementor_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->rtwwpge_plugin_name, plugin_dir_url( __FILE__ ) . 'js/rtwwpge-wordpress-pdf-generator-for-elementor-public.js', array( 'jquery' ), $this->rtwwpge_version, false );
		wp_enqueue_script( 'rtwwpge_global', RTWWPGE_URL.'admin/js/rtwwpge-wordpress-pdf-generator-for-elementor-global.js', array( 'jquery' ), $this->rtwwpge_version, false );
        wp_localize_script( $this->rtwwpge_plugin_name, 'rtwwpge_obj', array( 'ajax_url' => admin_url('admin-ajax.php'), 'some_thing_msg' => esc_html__('Some Thing Went Wrong! Please Try Again', 'rtwwpge-wordpress-pdf-generator-for-elementor') ) );
	}

	public function rtwwpge_dwnld_pdf()
	{
		if( isset( $_GET['rtwwpge_generate_pdf'] ) && isset( $_GET['rtwwpge_pdf_file'] ) && !empty( $_GET['rtwwpge_pdf_file'] ) )
		{
			$rtwwpge_file_path = RTWWPGE_PDF_DIR . '/' .sanitize_text_field( $_GET['rtwwpge_pdf_file'] );
			$rtwwpge_file_name = sanitize_text_field( $_GET['rtwwpge_pdf_file'] );
			header("Content-type:application/pdf");
			header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
			header("Cache-Control: post-check=0, pre-check=0", false);
			header("Pragma: no-cache");
			header("Content-Disposition:attachment;filename=$rtwwpge_file_name");
			readfile($rtwwpge_file_path);
			die();
		}
	}

	public function rtwwpge_grouped_prdt_price($rtwwpge_price)
	{
		$this->rtwwpge_grouped_prdt_price = $rtwwpge_price;
	}

	public function rtwwpge_variable_prdt_price($rtwwpge_price)
	{
		$this->rtwwpge_variable_prdt_price = $rtwwpge_price;
	}

	public function rtwwpge_convert_to_pdf( $rtwwpge_post_content )
	{
		// ini_set('display_errors', 1);
		// ini_set('display_startup_errors', 1);
		// ini_set('error_reporting', E_ALL);

		$rtwwpge_pdf_html = '';
		
		//for simple html dom
		require_once RTWWPGE_DIR.'/includes/simplehtmldom/simple_html_dom.php';
		$rtwwpge_dom_check_con = new simple_html_dom();
		 
		/* For Top Nav Tab*/
		$rtwwpge_check_the_con = false;
		$rtwwpge_dom_check_con->load($rtwwpge_post_content);
		foreach ($rtwwpge_dom_check_con->find('.rtwwpge_main') as $element) {
			$element->outertext = '';
			$rtwwpge_check_the_con = true;
		}
		$rtwwpge_post_content = $rtwwpge_dom_check_con->save();
		if($rtwwpge_check_the_con === false) {
			return;
		}

		global $post;
		global $woocommerce;
		if(empty( $this->rtwwpge_stng['rtwwpge_post_type'] ) )
		{
			return false;
		}
		if ( !array_key_exists( get_post_type(), $this->rtwwpge_stng['rtwwpge_post_type'] ) )
		{
			return false;
		}

		if ( isset( $this->rtwwpge_stng ['rtwwpge_file_name'] ) && $this->rtwwpge_stng ['rtwwpge_file_name'] == 'rtwwpge_post_name' ) 
		{
			if (isset($_SERVER['HTTP_X_GT_LANG']) && !empty($_SERVER['HTTP_X_GT_LANG'])) {
				$rtwwpge_file_path = RTWWPGE_PDF_DIR . '/' . $post->post_name . $_SERVER['HTTP_X_GT_LANG'].'.pdf';
				$rtwwpge_file_name = $post->post_name . $_SERVER['HTTP_X_GT_LANG'].'.pdf';
			}
			else
			{
				$rtwwpge_file_path = RTWWPGE_PDF_DIR . '/' . $post->post_name . '.pdf';
				$rtwwpge_file_name = $post->post_name . '.pdf';
			}
			
		} 
		else 
		{
			if (isset($_SERVER['HTTP_X_GT_LANG']) && !empty($_SERVER['HTTP_X_GT_LANG'])) {
				$rtwwpge_file_path = RTWWPGE_PDF_DIR . '/' .$post->ID. $_SERVER['HTTP_X_GT_LANG'].'.pdf';
				$rtwwpge_file_name = $post->ID. $_SERVER['HTTP_X_GT_LANG'].'.pdf';
			}
			else
			{
				$rtwwpge_file_path = RTWWPGE_PDF_DIR . '/' .$post->ID. '.pdf';
				$rtwwpge_file_name = $post->ID. '.pdf';
			}
			
		}
		
		/* Disable PDF Caching */
		$rtwwpge_pdf_cache = true;
		if(!file_exists($rtwwpge_file_path) || isset($this->rtwwpge_stng['rtwwpge_disable_cache']) && $this->rtwwpge_stng['rtwwpge_disable_cache'] == 1) {
			$rtwwpge_pdf_cache = false;
		}

		$rtwwpge_woo_cartpage = true;
		if ( is_plugin_active('woocommerce/woocommerce.php') && is_cart() ) {
			$rtwwpge_woo_cartpage = false;
		}

		if( $rtwwpge_pdf_cache == false || $rtwwpge_woo_cartpage == false)
		{
			$rtwwpge_pdf_title = get_the_title();
			$rtwwpge_post_type = get_post_type();

			$rtwwpge_eptid_css = $_POST['rtwwpge_elementor_id'];
			if ( isset($rtwwpge_eptid_css) && !empty($rtwwpge_eptid_css) ) {

				if( function_exists('is_multisite') && is_multisite() )
				{
					$this->rtwwpge_post_css_file_path = WP_CONTENT_URL.'/uploads/sites/'.get_current_blog_id().'/elementor/css/post-'.$rtwwpge_eptid_css.'.css';
				}
				else
				{
					$this->rtwwpge_post_css_file_path = WP_CONTENT_URL.'/uploads/elementor/css/post-'.$rtwwpge_eptid_css.'.css';
				}

				$rtwwpge_postcss_content = file_get_contents($this->rtwwpge_post_css_file_path);

				if ($rtwwpge_postcss_content === false)
				{ 
					$rtwwpge_cs = curl_init();
					curl_setopt($rtwwpge_cs, CURLOPT_URL, $this->rtwwpge_post_css_file_path);
					curl_setopt($rtwwpge_cs, CURLOPT_RETURNTRANSFER, true);
					$rtwwpge_postcss_content = curl_exec($rtwwpge_cs);
				}
			}
			$rtwwpge_postcss_content = str_replace('>', '', $rtwwpge_postcss_content);
			$rtwwpge_postcss_content = str_replace('  ', ' ', $rtwwpge_postcss_content);
			$rtwwpge_postcss_content = '<style>' .$rtwwpge_postcss_content. '
									.rtwwpge_main
									{
										display: none;
									}
                                    div
									{ 
										margin-top:0px;
										margin-bottom:0px;
										padding-top:0px;
										padding-bottom:0px;
									}
									.dummy,.rtw_wpge_main
									{
										display:none;
									}
									.elementor-row
									{
										width: 100%;
									}
									.elementor-column
									{
										float: left;
									}
									.elementor-column.elementor-col-10,
									.elementor-column[data-col="10"]
									{
										width: 10%;
									}
									.elementor-column.elementor-col-11,
									.elementor-column[data-col="11"]
									{
										width: 11.111%;
									}
									.elementor-column.elementor-col-12,
									.elementor-column[data-col="12"]
									{
										width: 12.5%;
									}
									.elementor-column.elementor-col-14,
									.elementor-column[data-col="14"]
									{
										width: 14.285%;
									}
									.elementor-column.elementor-col-16,
									.elementor-column[data-col="16"]
									{
										width: 16.666%;
									}
									.elementor-column.elementor-col-20,
									.elementor-column[data-col="20"]
									{
										width: 20%;
									}
									.elementor-column.elementor-col-25,
									.elementor-column[data-col="25"]
									{
										width: 25%;
									}
									.elementor-column.elementor-col-30,
									.elementor-column[data-col="30"]
									{
										width: 30%;
									}
									.elementor-column.elementor-col-33,
									.elementor-column[data-col="33"]
									{
										width: 33.333%;
									}
									.elementor-column.elementor-col-40,
									.elementor-column[data-col="40"]
									{
										width: 40%;
									}
									.elementor-column.elementor-col-50,
									.elementor-column[data-col="50"]
									{
										width: 50%;
									}
									.elementor-column.elementor-col-60,
									.elementor-column[data-col="60"]
									{
										width: 60%;
									}
									.elementor-column.elementor-col-66,
									.elementor-column[data-col="66"]
									{
										width: 66.666%;
									}
									.elementor-column.elementor-col-70,
									.elementor-column[data-col="70"]
									{
										width: 70%;
									}
									.elementor-column.elementor-col-75,
									.elementor-column[data-col="75"]
									{
										width: 75%;
									}
									.elementor-column.elementor-col-80,
									.elementor-column[data-col="80"]
									{
										width: 80%;
									}
									.elementor-column.elementor-col-83,
									.elementor-column[data-col="83"]
									{
										width: 83.333%;
									}
									.elementor-column.elementor-col-90,
									.elementor-column[data-col="90"]
									{
										width: 90%;
									}
									.elementor-column.elementor-col-100,
									.elementor-column[data-col="100"]
									{
										width: 100%;
									}
									.elementor-widget-wrap
									{
										width: 100%;
									}
									.elementor-widget-heading .elementor-heading-title
									{
										margin: 0;
										line-height: 1;
										margin-bottom: 5px;
									}
									.elementor-widget-heading .elementor-heading-title a
									{
										color: inherit;
									}
									.elementor-column-wrap
									{
										width: 100%;
									}
									.elementor-widget-image-box.elementor-image-box-content
									{
										width: 100%;
									}
									.elementor-widget-image-box.elementor-image-box-description
									{
										margin: 0;
									}
									.elementor-widget-image-box .elementor-image-box-wrapper
									{
										text-align: center;
									}
									.elementor-image-box-wrapper
									{
                                        margin-top: 15px;
									}
									.elementor-widget-image 
									{
										text-align: center;
									}
									.elementor-widget-icon-box .elementor-icon-box-wrapper
									{
										text-align: center;
										margin-top: 5%;
									}
									.elementor-widget-icon-box .elementor-icon-box-description
									{
										margin: 0;
									}
									.elementor-widget-html 
									{
										margin-top: 10px;
									}
									.elementor-image-gallery
									{
										margin-top: 15px;
									}
									.elementor-image-gallery.gallery-columns-4.gallery-item
									{
										max-width: 25%;
									}
									.gallery.gallery-columns-4.gallery-item
									{
										width: 25%;
									}
									.elementor-image-gallery.gallery-item
									{
										float: left;
										text-align: center;
									}
									.elementor-testimonial-wrapper 
									{
										text-align: center;
										margin-bottom: 10px;
										margin-top: 15px;
									}
									.elementor-testimonial-wrapper .elementor-testimonial-content 
									{
										font-size: 1.1em;
										margin-bottom: 20px;
									}
									.elementor-testimonial-wrapper .elementor-testimonial-meta 
									{
										width: 100%;
										line-height: 1;
									}
									.elementor-testimonial-wrapper.elementor-testimonial-meta.elementor-testimonial-image img
									{
									   max-width: none;
									}
									.elementor-testimonial-wrapper.elementor-testimonial-text-align-left
									{
										text-align: left;
									}
									.elementor-testimonial-wrapper.elementor-testimonial-text-align-right 
									{
										text-align: right;
									}
									.elementor-testimonial-wrapper.elementor-testimonial-name
									{
										line-height: 1.5;
									}
									.elementor-testimonial-wrapper.elementor-testimonial-job
									{
										font-size: .85em;
									}
									.elementor-widget-wc-add-to-cart .elementor-button-wrapper .elementor-button
									{
									   line-height: 1;
									   background-color: #818a91;
									   padding: 8px;
									   border-radius: 3px;
									   color:#fff;
									   border: 1px solid;
									   width:80px;
									   font-size: 12px;
									}
									.swiper-slide-contents .elementor-button
									{
									   line-height: 1;
									   padding: 10px 20px;
									   border-radius: 3px;
									   color:#fff;
									   width:60px;
									   font-size: 12px;
									}
									.elementor-price-table__footer .elementor-button
									{
									   line-height: 1;
									   background-color: #818a91;
									   padding: 8px; 16px;
									   width:75px;
									   border-radius: 3px;
									   font-size: 12px;
									}
									.elementor-price-table__button.elementor-button.elementor-size-md
									{
										color:#fff;
									}
									.elementor-button
									{
									   line-height: 1;
									   padding: 10px 20px;
									   border-radius: 3px;
									   width:80px;
									   font-size: 12px;
									}
									.elementor-menu-cart__toggle .elementor-button-text 
									{
										margin-right: .3em;
									}
									.elementor-menu-cart__toggle .elementor-button 
									{
										background: transparent;
										color: #818a91;
										border: 1px solid;
										border-color: inherit;
									}
									.elementor.elementor-custom-embed
									{
										line-height: 0;
									}
									.elementor-widget-google_maps iframe
									{
										height: 300px;
									}
									.elementor-star-rating
									{
										color: #ccd6df;
										float: left;
										width:100%;
									}
									.elementor-star-rating i
									{
										float: left;
										font-style: normal;
									}
									.elementor-pagination-position-outside.swiper-container
									{
										padding-bottom: 30px;
									}
									.swiper-slide-image
									{
										margin: 10px;
									}
									.elementor-widget-image-carousel.swiper-slide
									{
										text-align: center;
								    }
									.elementor-carousel-image
									{
										height: 250px;
									}
									.elementor-widget-image-carousel.swiper-container.swiper-slide figure
									{
										line-height: inherit;
									}
									.elementor-slides .swiper-slide-inner .elementor-slide-heading 
									{
										font-size: 25px;
										font-weight: bold;
										line-height: 1;
										margin-bottom: 10px;
									}
									.swiper-slide-bg
									{
										background-color: #833ca3;
										height: 280px;
									}
									.swiper-slide
									{
										width: 100%;
									}
									.elementor--h-position-center .swiper-slide-inner
									{
									   text-align: center;
									}
									.elementor--v-position-middle .swiper-slide-inner
									{
										text-align: center;
									}
									.elementor-slides .swiper-slide-inner
									{
										padding: 50px;
										color: #fff;
										margin-top: 40px;
						            }
									.elementor-slides .swiper-slide-inner .elementor-slide-description 
									{
										font-size: 17px;
										line-height: 1.4;
										margin-bottom: 10px;
									}
									.swiper-slide-inner .elementor-button
									{
										width: 81px;
										text-decoration: none;
									    margin-left: auto;
										margin-right: auto;
                                    }
									.elementor-testimonial--align-center .elementor-testimonial 
									{
										text-align: center;
									}
									.elementor-testimonial--align-right .elementor-testimonial 
									{
										text-align: right;
									}
									.elementor-testimonial--align-left .elementor-testimonial 
									{
										text-align: left;
									}
									.elementor-widget-icon-box.elementor-position-left .elementor-icon-box-wrapper
									{
										text-align: left;
									}
									.elementor-widget-icon-box.elementor-position-right .elementor-icon-box-wrapper
									{
										text-align: right;
									}
									.elementor-widget-testimonial-carousel .elementor-testimonial__text 
									{
										font-size: 1.3em;
										font-style: italic;
										line-height: 1.5;
									}
									.swiper-pagination-bullets,.swiper-pagination-custom,.swiper-pagination-fraction
									{
										bottom: 5px;
										left: 0;
										width: 100%;
									}
									.swiper-pagination
									{
										text-align: center;
									}
								    .elementor .elementor-element ul .elementor-icon-list-items
									{
										padding: 0;
										margin-top: 10px;
									}
									.elementor-widget .elementor-icon-list-items
									{
										margin-top: 10px;
										padding: 0;
										list-style-type: none;
									}
									.elementor-inline-items .elementor-icon-list-item
									{
										margin: 0;
										padding: 0;
										float: left;
										width: 90px;
									}
									.elementor-widget .elementor-icon-list-items.elementor-inline-items .elementor-icon-list-item
									{
										margin-right: 8px;
										margin-left: 8px;
									}
									.elementor-counter
									{
										margin-top: 5px;
									}
									.elementor-counter .elementor-counter-number-wrapper
									{
										font-size: 40px;
										font-weight: bold;
							            line-height: 1;
									}
									.elementor-counter .elementor-counter-number-prefix
									{
										text-align: right;
									}
									.elementor-counter .elementor-counter-number-suffix
									{
										text-align: left;
									}
									.elementor-counter .elementor-counter-title
									{   
										text-align: center;
										font-size: 15px;
										font-weight: bold;
										line-height: 2.5;
									}
                                    .elementor-widget-progress
									{
										text-align: left;
									}
									.elementor-progress-wrapper
									{
									    background-color: #eee;
                                        color: #fff;
                                        height: 32px;
                                        border-radius: 2px;
									}
									.elementor-progress-bar
									{
										background-color: #818a91;
										font-size: 11px;
										height: 30px;
								        border-radius: 2px;
									}
									.elementor-progress-text
									{
										padding-left: 15px;
										padding-top: 10px;
									}
									.elementor-progress-percentage
									{
										padding-right: 15px;
										float: right;
										padding-top: -15px;
                                        width: 25px;
									}
                                    .elementor-accordion
									{
										text-align: left;
										margin-top: 15px;
									}
									.elementor-widget-tabs
									.elementor-tabs-view-horizontal
									.elementor-tab-content
									{
										border: none solid solid;
									}
									.elementor-widget-tabs
									.elementor-tab-content
									{
										padding: 18px;
										border: 1px solid #ccc;
									}
									.elementor-accordion
									.elementor-accordion-item
									{
										border: 1px solid #d4d4d4;
									}
									.elementor-accordion
									.elementor-tab-title
									{
										margin: 0;
										padding: 15px 20px;
										font-weight: bold;
										line-height: 1;
									}
									.elementor-accordion
									.elementor-tab-title
									.elementor-accordion-icon
									.elementor-accordion-icon-left
									{
										float: left;
										text-align: left;
									}
									.elementor-accordion
									.elementor-tab-content
									{
										padding: 13px 18px;
										border-top: 1px solid #d4d4d4;
									}
                                    .elementor-toggle
									{
										text-align: left;
										margin-top: 10px;
									}
									.elementor-toggle
									.elementor-tab-title
									{
										font-weight: bold;
										line-height: 1;
										margin: 0;
										padding: 15px;
										border-bottom: 1px solid #d4d4d4;
									}
									.elementor-toggle
									.elementor-tab-title
									.elementor-active
									{
										border-bottom: none;
									}
									.elementor-toggle
									.elementor-tab-title
									.elementor-toggle-icon
									.elementor-toggle-icon-left
									{
										float: left;
										text-align: left;
									}
									.elementor-toggle
									.elementor-tab-content
									{
										padding: 13px;
										border-bottom: 1px solid #d4d4d4;
										
									}
									.elementor-toggle-item
									.elementor-tab-title
									{
										border-bottom: none;
									}
									.elementor-alert.elementor-alert-info
									{
										color: #31708f;
									    background-color: #d9edf7;
										border-color: #bcdff1;
										margin-top: 15px;
									}
									#search-2
									{
										margin-top: 15px;
									}
									.elementor-widget-testimonial-carousel .swiper-slide
									{
										padding: 20px;
									}
									.elementor-alert
									{
										padding: 20px;
										border-left: 5px solid ;
										text-align: left;
									}
									.elementor-alert.elementor-alert-title
									{
										float: left;
                                        width: 100%;
										font-weight: bold;
									}
									.elementor-alert.elementor-alert-description
									{
										font-size: 13px;
									}
									.elementor-alert button.elementor-alert-dismiss
									{
										right: 10px;
										top: 10px;
										padding: 3px;
										font-size: 20px;
										line-height: 1;
										background: 
										transparent;
										color: inherit;
										border: none;
									}
									.elementor-widget-tabs .elementor-tabs 
									{
										text-align: left;
										margin-bottom: 10px;
										margin-top: 10px;
									}
									.elementor-widget-tabs .elementor-tabs-wrapper 
									{
										overflow: hidden;
									}
									.elementor-widget-tabs.elementor-tabs-view-horizontal.elementor-tab-desktop-title.elementor-active
									{
										border-bottom-style: none;
									}
									.elementor-widget-tabs .elementor-tab-desktop-title.elementor-active 
									{
										border-color: #d4d4d4;
									}
								    .elementor-tabs-view-horizontal.elementor-widget-tabs .elementor-tab-desktop-title 
									{
										float: left;
									}
									.elementor-widget-tabs .elementor-tab-desktop-title 
									{
										padding: 16px 21px;
										font-weight: bold;
										line-height: 1;
										border: 1px solid #ccc ;
										border-bottom: none;
									}
									.elementor-tab-title elementor-tab-desktop-title
									{
										border-bottom: none;
									}
									.elementor-widget-tabs .elementor-tabs-content-wrapper 
									{
										border: 1px #d4d4d4;
									}
									.elementor-tabs .elementor-tab-mobile-title 
									{
										display: none;
									}
									.elementor-widget-tabs .elementor-tab-mobile-title 
									{
										padding: 10px;
									}
									.elementor-tab-title a 
									{
										color: inherit;
									}
									.gallery .gallery-columns-3 .gallery-item 
									{
										width: 33.3%;
									}
									.gallery .gallery-item 
									{
										float: left;
									}
									.product_list_widget
									{
										list-style: none;
										border: 1px solid;
										box-shadow: 0px 0px 8px gray;
									}
									.product_list_widget li
									{
										border-bottom: 1px solid #ccc;
										padding: 1em 0;
										margin-right: 40px;
									}
									.elementor-counter-number-wrapper
									{
                                        margin-left: 43%;
									}
									h5
									{
										font-weight: 300;
										margin: 0 0 0.5407911001em;
										margin-top: 15px;
									}
									#wp-calendar
									{
										margin: 0 auto;
									}
									table caption 
									{
										padding-top: 0.75rem;
                                        padding-bottom: 0.75rem;
                                        color: #6c757d;
										text-align: left;
									}
									.table 
									{
										width: 100%;
										max-width: 100%;
										margin-bottom: 1rem;
										background-color: transparent;
									}
									table 
									{   
										border-collapse: collapse;
									}
									#wp-calendar thead tr th
									{
										background-color: #f7f7f7;
									}
									table td, table th
									{
										padding: 2em 4.416em;
									}
									.table-bordered thead th, .table-bordered thead td
									{
										border-bottom-width: 2px;
									}
									.table thead th
									{
										vertical-align: bottom;
										border-bottom: 2px solid #dee2e6;
										border-bottom-width: 2px;
									}
									.table-bordered th, .table-bordered td
									{
										border: 1px solid #dee2e6;
									}
									.table th, .table td
									{
										padding: 0.75rem;
										vertical-align: top;
										text-align: center;
									}
									.search-field
									{
										padding: 15px;
										background-color: #f2f2f2;
									    color: #43454b;
									    border: 0;
										box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.125);
										width: 25%;
									}
									.search-submit 
									{
										border: 0;
										padding: 15px;
									}
									.textwidget p
									{
										margin: 0 0 1.41575em;
									}
									.elementor-posts--thumbnail-top .elementor-post
									{
										float: left;
									}
									.elementor-posts--skin-classic .elementor-post 
									{
										overflow: hidden;
									}
									.elementor-posts-container .elementor-post
									{
										padding: 0;
										margin: 0;
									}
									.elementor-posts--thumbnail-top .elementor-post__text 
									{
										width: 100%;
									}
									.elementor-posts .elementor-post__title 
									{
										font-size: 18px;
										margin: 0;
									}
									.elementor-posts .elementor-post__meta-data 
									{
										font-size: 12px;
										margin-bottom: 13px;
										color: #adadad;
									}
									.elementor-posts .elementor-post__excerpt 
									{
										margin-bottom: 10px;
									}
									.elementor-posts .elementor-post__excerpt p 
									{
										margin: 0;
										line-height: 1.5em;
										color: #777;
										font-size: 11px;
									}
									.elementor-posts .elementor-post__read-more 
									{
										font-size: 10px;
										font-weight: bold;
									}
									.elementor-posts .elementor-post__badge 
									{
										background: #818a91;
									    color: #fff;
										font-size: 9px;
										padding: .4em 1em;
										line-height: 1;
										font-weight: bold;
										border-radius: 999px;
										width: 67px;
										text-align: center;
										float: right;
									}
									.elementor-post__badge
									{
										margin-top: -20px;
									}
									.elementor-post__avatar 
									{
										margin-top: -35px;
										margin-left: 10px;
									}
									.elementor-author-box__avatar 
									{
										margin-right: 25px;
										width: 120px;
									}
									.elementor-posts-container.elementor-posts.elementor-posts--skin-cards.elementor-grid
									{
										margin-top: 5px;
									}
									.elementor-post__card
									{
									   border: 1px solid #e1e8ed;
                                       border-radius: 5px;
									   padding: 0;
									   margin: 10px;
									   width: 100%;
									   height: 50%;
									}
									.elementor-posts .elementor-post__card .elementor-post__text
									{
										padding-left: 10px;
										margin-bottom: 0;
									}
									.elementor-posts .elementor-post__card .elementor-post__excerpt, .elementor-posts .elementor-post__card .elementor-post__title 
									{
										margin-bottom: 22px;
									}
									.elementor-posts .elementor-post__card .elementor-post__title 
									{
										font-size: 13px;
									}
									.elementor-posts .elementor-post__card .elementor-post__read-more 
									{
										margin-bottom: 20px;
									}
									.elementor-posts .elementor-post__card .elementor-post__meta-data 
									{
										padding: 10px 20px;
										margin-bottom: 0;
										border-top: 1px solid #eaeaea;
									}
									.elementor-author-box__text 
									{
										margin-top: -105px;
										margin-left: 90px;
										width: 400px;
										margin-bottom: 50px;
									}
									.elementor-author-box__name 
									{
										font-size: 20px;
										margin-bottom: 5px;
										color: #F61E81;
									}
									.elementor-author-box
									{
										margin-top: 10px;
									}
									.elementor-author-box__bio, .elementor-author-box__bio p 
									{
										margin-bottom: 3.8em;
									}
								   .elementor-field-group .elementor-field-textual 
								   {
									   width: 100%;
									   border: 1px solid #818a91;
									   color: #373a3c;
									   line-height: 1.4;
                                       font-size: 15px;
									   min-height: 40px;
									   max-width: 100%;
									}
									.elementor-form .elementor-button .elementor-size-sm 
									{
										min-height: 40px;
									}
									.elementor-form .elementor-button 
									{
										padding-top: 0;
										padding-bottom: 0;
										border: 0;
										font-weight: bold;
										width: 100%;
									}
									.elementor-login .elementor-lost-password, .elementor-login .elementor-remember-me 
									{
										font-size: .85em;
									}
									.elementor-item
									{
										padding: 13px 20px;
									}
									.elementor-nav-menu, .elementor-nav-menu li, .elementor-nav-menu ul 
									{
										padding: 0;
									}
									.elementor-nav-menu
									{
										list-style: none;
									}
									.elementor-headline
									{
										font-size: 43px;
										line-height: 1.2;
									}
									.elementor-price-list
									{
										list-style: none;
										padding: 0;
										margin: 0;
									}
									.elementor-price-list li
									{
										margin: 0;	
									}
									.elementor-price-list .elementor-price-list-item .elementor-price-list-header
									{
										font-size: 19px;
										font-weight: bold;
										margin-bottom: 10px;
									}
									.elementor-price-list-separator
									{
										width: 75%;
										margin-left: 145px;
										margin-right: 10px;
										margin-top: -11px;
									}
									.elementor-price-list-price 
									{
									    width: 5%;
										float: right;
										margin-top: -11px;
										margin-right: -10px;
										text-decoration: underline;
									}
									.elementor-price-list .elementor-price-list-item p .elementor-price-list-description
									{
										font-size: 14px;
										margin: 0;
									}
									.elementor-price-table
									{
										text-align: center;
										background-color: #f7f7f7;
										margin-top: 10px;
										margin-bottom: 15px;
									}
									.elementor-price-table .elementor-price-table__header
									{
										padding: 10px;
									}
									.elementor-price-table__header
									{
										background: #555;
										height: 60px;
									}
									.elementor-price-table .elementor-price-table__heading
									{
										margin: 0;
										padding: 0;
										line-height: 1.2;
										font-size: 24px;
										font-weight: bold;
									}
									.elementor-price-table__heading
									{
										color: #fff;
									}
									.elementor-price-table .elementor-price-table__subheading
									{
										font-size: 13px;
										font-weight: bold;
									}
									.elementor-price-table__subheading
									{
										color: #fff;
									}
									.elementor-price-table .elementor-price-table__price
									{
									    font-weight: bold;
										font-size: 40px;
										padding: 20px;
									}
								    .elementor-price-table .elementor-price-table__currency, .elementor-price-table .elementor-price-table__fractional-part 
									{
										line-height: 1;
										font-size: .3em;
									}
									.elementor-price-table__fractional-part
									{
										margin-left: 30px;
										margin-top: -65px
									}
									.elementor-price-table .elementor-price-table__integer-part
									{
										line-height: .8;
										margin-bottom: 30px;
										margin-left: -30px;
									}
									.elementor-price-table .elementor-price-table__price .elementor-typo-excluded
									{
										line-height: 1;
										font-weight: bold;
										font-size: 15px;
										width: 100%;
                                        margin-top: 25px;
									}
									.elementor-price-table__currency
									{
										width: 46%;
										margin-left: 21%;
									}
									.elementor-price-table .elementor-price-table__features-list
									{
										list-style-type: none;
										margin: 0;
										padding: 0;
										line-height: 1;
									}
									.elementor-price-table .elementor-price-table__footer
									{
										padding: 20px;
										margin-top: 0;
									}
									.elementor-price-table .elementor-price-table__features-list li
									{
										font-size: 14px;
										margin: 0;
										padding: 5px;
										border-bottom: 1px solid #c6b1b1;
									}
									.elementor-price-table .elementor-price-table__features-list li .elementor-price-table__feature-inner
									{
										margin-left: 15px;
										margin-right: 15px;
									}
									.elementor-price-table .elementor-price-table__features-list i
									{
										margin-right: 10px;
										font-size: 1.3em;
									}
									.elementor-price-table__ribbon
									{
										width: 30%;
										float: right;
										margin-top: -30px;
										margin-right: -20px;
									}
									.elementor-price-table__ribbon-inner
									{
										text-align: center;
										font-size: 12px;
										background: #000;
										color: white;
										line-height: 2;
                                    }
									.elementor-button.elementor-size-md
									{
										font-size: 16px;
										padding: 15px 30px;
										border-radius: 4px;
									}
									.elementor-price-table .elementor-price-table__additional_info
									{
										font-size: 13px;
										line-height: 1.4;
									}
									.elementor-flip-box__layer
									{
										height: 280px;
										margin-top: 10px;
									}
									.elementor-flip-box__front
									{
										background-color: #1abc9c;
									}
									.elementor-flip-box__layer__overlay
									{
										text-align: center;
									}
									.elementor-flip-box .elementor-icon-wrapper
									{
										margin-bottom: 20px;
									}
									.elementor-flip-box__layer__title
									{
										line-height: 1;
										font-weight: bold;
									}
									.elementor-flip-box__layer__description, .elementor-flip-box__layer__title
									{
										color: #fff;
									}
									.elementor-flip-box__layer__title
									{
										font-size: 21px;
										padding-top: 96px;
									}
									.elementor-flip-box__layer__description
									{
										font-size: 14px;
										margin-bottom: 10px;
									}
									.elementor-flip-box__back
									{
										background-color: #4054b2;
									}
									.elementor-flip-box__button .elementor-button
									{
										border: 2px solid #fff;
								        color: #fff;
									}
									.elementor-cta
									{
										margin-top: 10px;
									}
									.elementor-cta__bg
									{
									  height: 200px;
									  background-size: cover;
									  background-position: 50%;
									}
									.elementor-cta--layout-image-above .elementor-cta__bg-wrapper
									{
										width: 100%;
									}
									.elementor-cta--skin-classic .elementor-cta__content
									{
										width: 100%;
									}
									.elementor-cta__content
									{
										padding: 25px;
										text-align: center;
										background-color: #DF2A2A;
									}
									.elementor-cta--skin-classic .elementor-cta__button.elementor-button, .elementor-cta--skin-classic .elementor-cta__content-item, .elementor-cta--skin-classic .elementor-cta__content-item .elementor-icon
									{
										color: #55595c;
										border-color: #55595c;
									}
									.elementor-cta__content, .elementor-cta__content-item
									{
										color: #fff;
									}
									.elementor-cta__content-item
									{
										margin: 0;
									}
									.elementor-cta__title
									{
										font-size: 20px;
									}
									.elementor-widget-reviews.elementor-pagination-type-bullets .swiper-container, .elementor-widget-reviews.elementor-pagination-type-fraction .swiper-container, .elementor-widget-testimonial-carousel.elementor-pagination-type-bullets .swiper-container, .elementor-widget-testimonial-carousel.elementor-pagination-type-fraction .swiper-container
									{
										padding-bottom: 15px;
									}
									.elementor-skin-carousel .elementor-main-swiper, .elementor-skin-coverflow .elementor-main-swiper
									{
										height: 230px;
										margin: 10px;
									}
									.elementor-widget-reviews .elementor-main-swiper, .elementor-widget-testimonial-carousel .elementor-main-swiper
									{
										width: 100%;
									}
									.elementor-widget-reviews .swiper-slide
									{
										background-color: #fff;
									    border: 1px solid #e1e8ed;
										border-radius: 5px;
									}
									.elementor-widget-reviews.elementor-review--has-separator .elementor-testimonial__header 
									{
										border-bottom: 1px solid #e1e8ed;
									}
									.elementor-widget-reviews .elementor-testimonial__content, .elementor-widget-reviews .elementor-testimonial__header
									{
										padding-left: 15px;
										padding-right: 15px;
									}
									.elementor-widget-testimonial-carousel .elementor-testimonial__image img 
									{
										width: 50px;
										height: 50px;
									}
									.elementor-testimonial__footer cite, .elementor-testimonial__header cite
									{
										font-style: normal;
										font-size: 14px;
									}
									.elementor-testimonial--layout-image_inline .elementor-testimonial__footer 
									{
										margin-top: 25px;
									}
									.elementor-widget-reviews .elementor-testimonial__name
									{
										color: #1c2022;
									}
									.elementor-testimonial__name
									{
										font-weight: bold;
									}
									.elementor-widget-reviews .elementor-testimonial__title
									{
										color: #697882;
										font-size: 12.5px;
										font-weight: bold;
									}
									.elementor-widget-reviews .elementor-testimonial__icon.elementor-icon-twitter
									{
										color: #1da1f2;
									}
									.elementor-widget-reviews .elementor-testimonial__icon
									{
										margin-left: 97%;
										font-size: 10px;
										margin-top: -90px;
										margin-bottom: 78px;
									}
									.elementor-testimonial__icon .elementor-screen-only
									{
										display: none;
									}
									.elementor-widget-reviews .elementor-testimonial__text
									{
										font-size: 14px;
										line-height: 20px;
									}
									.elementor-portfolio-item__img .elementor-post__thumbnail
									{
										float: left;
										width: 160px;
									}
									.elementor-toc__header-title 
									{
										font-size: 18px;
										margin: 0;
									}
									.elementor-blockquote--skin-border .elementor-blockquote
									{
										border-color: #e6e9ec;
										border-style: solid;
										border-left-width: 7px;
										padding-left: 20px;
										margin-top: 10px;
									}
									.elementor-widget-blockquote blockquote
									{
										margin: 0;
										padding: 0;
									    border: 0 none;
									}
									.elementor-blockquote__author, .elementor-blockquote__content
									{
										margin-bottom: 0;
										font-style: normal;
									}
									.elementor-blockquote footer
									{
										margin-top: 12px;
									}
									.elementor-blockquote__author
									{
										font-weight: bold;
									}
									.elementor-blockquote__tweet-button
									{
										background-color: #1da1f2;
										color: #fff;
										font-size: 10px;
										border-radius: 100em;
										width: 45px;
										float: right;
										margin-top: -25px;
										padding: .7em 1.2em;
										margin-right: 40px;
									}
									.elementor-blockquote__tweet-button span
									{
										font-weight: bold;
										margin-left: 15px;
									}
									.rtwwpge-grid-container
									{
										float: left;
									}
									.rtwwpge-post-title
									{
										font-size: 12px;
										text-align: center;
									}
									.elementor-grid-1 .rtwwpge-grid-container
									{
										width: 100%;
									}
									.elementor-grid-2 .rtwwpge-grid-container
									{
										width: 50%;
									}
									.elementor-grid-3 .rtwwpge-grid-container
									{
										width: 33.33%;
									}
									.elementor-grid-4 .rtwwpge-grid-container
									{
										width: 25%;
									}
									.elementor-grid-5 .rtwwpge-grid-container
									{
										width: 20%;
									}
									.elementor-grid-6 .rtwwpge-grid-container
									{
										width: 16.66%;
									}
									.elementor-grid-1 .elementor-grid-item
									{
										width: 100%;
									}
									.elementor-grid-2 .elementor-grid-item
									{
										width: 50%;
									}
									.elementor-grid-3 .elementor-grid-item
									{
										width: 33.33%;
									}
									.elementor-grid-4 .elementor-grid-item
									{
										width: 25%;
									}
									.elementor-grid-5 .elementor-grid-item
									{
										width: 20%;
									}
									.elementor-grid-6 .elementor-grid-item
									{
										width: 16.66%;
									}
									.gallery-columns-1 .gallery-item
									{
										width: 100%;
									}
									.gallery-columns-2 .gallery-item
									{
										width: 50%;
									}
									.gallery-columns-3 .gallery-item
									{
										width: 33.33%;
									}
									.gallery-columns-4 .gallery-item
									{
										width: 25%;
									}
									.gallery-columns-5 .gallery-item
									{
										width: 20%;
									}
									.gallery-columns-6 .gallery-item
									{
										width: 16.66%;
									}
									.gallery-columns-7 .gallery-item
									{
										width: 14.3%;
									}
									.gallery-columns-8 .gallery-item
									{
										width: 12.5%;
									}
									.gallery-columns-9 .gallery-item
									{
										width: 11.11%;
									}
									.gallery-columns-10 .gallery-item
									{
										width: 10%;
									}
									.elementor a 
									{
										box-shadow: none;
										text-decoration: none;
									}
									.calendar_wrap span 
									{
                                        color: #9a7918;
									}
									.woocommerce-breadcrumb 
									{
										margin-top: 15px;
									}
									.elementor-button-wrapper 
									{
										margin-top: 18px;
										padding: 10px;
									}
									.elementor-widget-button .elementor-button-wrapper .elementor-button
									{
									   font-size: 12px;
									   text-align: center;
									   padding: 10px 20px;
									   border-radius: 3px;
									   width:55px;
									   color: white;
									}
									.elementor-widget-button .elementor-button-wrapper div
									{
									   background-color: #23A455;
									}
									.elementor-menu-cart__wrapper 
									{
										margin-top: 15px;
									}
									.elementor-divider-separator
									{
										border: 1px solid;
										margin: 10px;
									}
									.elementor-divider
									{
										margin-top:15px;
									}
									.elementor-nav-menu__align-center .elementor-nav-menu
									{
										margin-left: 40%;
									}
									.elementor-widget-countdown
									{
										margin-top: 10px;
										margin-bottom: 10px;
									}
									.elementor-widget-countdown .elementor-countdown-item 
									{
										background-color: #6ec1e4;
                                    }
									.elementor-widget-countdown .elementor-countdown-item
									{
										color: #fff;
										padding: 10px 0;
										text-align: center;
										float: left;
										width: 170px;
									}
									.elementor-widget-countdown .elementor-countdown-label
									{
										font-size: 15px;
										line-height: 1;
									}
									.elementor-widget-countdown .elementor-countdown-digits
									{
										font-size: 30px;
									}
									.woocommerce .woocommerce-MyAccount-navigation ul
									{
										list-style-type: none;
										margin: 0;
										padding: 0;
									}
									.woocommerce-MyAccount-navigation
									{
										float: left;
										width: 30%;
										padding-top: 35px;
									}
									.woocommerce .woocommerce-MyAccount-navigation ul li
									{
										margin-bottom: 6px;
									}
									.woocommerce-MyAccount-content
									{
										float: right;
										width: 70%;
										padding-top: 20px;
									}
									.elementor-post__thumbnail .attachment-medium
									{
										width: 100%;
										height: 300px;
									}
									.alert.alert-info
									{
										color: #0c5460;
										background-color: #d1ecf1;
										border-color: #bee5eb;
										padding: 0.75rem 1.25rem;
										margin-bottom: 1rem;
										border: 1px solid transparent;
										border-radius: 0.25rem;
									}
									.product-category
									{
										float: left;
									}
									.elementor-products-columns-1 .product-category
									{
										width: 100%;
									}
									.elementor-products-columns-2 .product-category
									{
										width: 50%;
									}
									.elementor-products-columns-3 .product-category
									{
										width: 33.33%;
									}
									.elementor-products-columns-4 .product-category
									{
										width: 25%;
									}
									.elementor-products-columns-5 .product-category
									{
										width: 20%;
									}
									.elementor-products-columns-6 .product-category
									{
										width: 16.66%;
									}
									.elementor-products-columns-7 .product-category
									{
										width: 14.3%;
									}
									.elementor-products-columns-8 .product-category
									{
										width: 12.5%;
									}
									.elementor-products-columns-9 .product-category
									{
										width: 11.11%;
									}
									.elementor-products-columns-10 .product-category
									{
										width: 10%;
									}
									.elementor-products-columns-11 .product-category
									{
										width: 9.09%;
									}
									.elementor-products-columns-12 .product-category
									{
										width: 8.33%;
									}
									.woocommerce table.shop_table 
									{
										border: 1px solid rgba(0,0,0,.1);
										margin: 0 -1px 24px 0;
										text-align: left;
										width: 100%;
									}
									.woocommerce table.shop_table th 
									{
										padding: 9px 12px;
										line-height: 1;
										font-size: 10px;
									}
									.woocommerce table.shop_table td
									{
										border-top: 1px solid rgba(0,0,0,.1);
                                        padding: 9px 12px;
                                        line-height: 1.5em;
									}
									.woocommerce a.remove 
									{
										font-size: 1.5em;
										text-align: center;
										line-height: 1;
										border-radius: 100%;
										text-decoration: none;
										font-weight: bold;
										border: 0;
									}
									.woocommerce 
									{
										margin-top: 5px;
									}
									.woocommerce #content table.cart td.actions .input-text, .woocommerce table.cart td.actions .input-text, .woocommerce-page #content table.cart td.actions .input-text, .woocommerce-page table.cart td.actions .input-text
									{
										width: 80px;
									}
									.woocommerce .cart-collaterals .cart_totals, .woocommerce-page .cart-collaterals .cart_totals
									{
										float: right;
										width: 48%;
									}
									.wc-proceed-to-checkout .checkout-button 
									{
										font-size: 16px;
										font-weight: bold;
										color: white;
									}
									.elementor-share-buttons--view-icon-text .elementor-grid .elementor_griditem
									{
										float: left;
										width: 20%;
										padding: 10px;
									}
									.elementor-share-buttons--view-icon .elementor-grid .elementor_griditem
									{
										float: left;
										padding: 10px;
										width: 5%;
										text-align: center;
									}
									.elementor-share-buttons--view-text .elementor-share-btn__text
									{
										padding-top: 27px;
										margin-right: 15px;
									}
									.elementor-share-buttons--view-text .elementor-share-btn
									{
										text-align: center;
									}
									.elementor-share-buttons--view-text .elementor-grid-item.elementor_griditem
									{
										width: 20%;
										float: left;
										padding: 10px;
									}
									.product .button 
									{
										background-color: #0be1af;
										color: #333333;
										border: 2px solid #eeeeee;
										margin-left: 10px;
										margin-right: 10px;
										font-weight: bold;
									}
									.product .woocommerce-Price-amount.amount
									{
										margin-bottom: 3px;
										color: green;
										font-size: 12px;
										font-weight: bold;
									}
									.elementor-prd .woocommerce-Price-amount.amount
									{
										margin-left: 12px;
									}
									.product
									{
										float: left;
										list-style: none;
										text-align: center;
										font-size: 11px;
									}
									.elementor-widget-woocommerce-products .products li
									{
										box-shadow: 0 0 8px 0 rgba(0,0,0,0.2);
										border-radius: 5px;
										height: 180px;
										margin-bottom: 15px;
									}
									.products li
									{
										box-shadow: 0 0 8px 0 rgba(0,0,0,0.2);
										border-radius: 5px;
										height: 180px;
										margin-bottom: 15px;
									}
									.star-rating
									{
										line-height: 1.618;
										font-weight: bold;
									}
									.woocommerce-loop-product__title
									{
										font-size: 12px;
										color: black;
										font-weight: bold;
									}
									.columns-1 .product
									{
										width: 100%;
									}
									.columns-2 .product
									{
										width: 50%;
									}
									.columns-3 .product
									{
										width: 33.33%;
									}
									.columns-4 .product
									{
										width: 25%;
									}
									.columns-5 .product
									{
										width: 20%;
									}
									.columns-6 .product
									{
										width: 16.66%;
									}
									.columns-7 .product
									{
										width: 14.3%;
									}
									.columns-8 .product
									{
										width: 12.5%;
									}
									.columns-9 .product
									{
										width: 11.11%;
									}
									.columns-10 .product
									{
										width: 25%;
									}
									.columns-11 .product
									{
										width: 9.09%;
									}
									.columns-12 .product
									{
										width: 8.33%;
									}
									.onsale
									{
										padding: 0;
										border: 1px solid;
										font-size: 0.875em;
										font-weight: bold;
										margin-bottom: 1em;
										border-radius: 3px;
									}
									.elementor-prd-img
									{
										margin-left: 90%;
									}
									.wc-proceed-to-checkout
									{
										border: 1px solid;
										text-align: center;
										padding: 5px;
										background: black;
									}
									.elementor-star-rating__wrapper
									{
										margin-top: 15px;
									}
									.elementor-star-rating--align-center .elementor-star-rating__wrapper
									{
										text-align: center;
									}
									.elementor-star-rating--align-right .elementor-star-rating__wrapper
									{
										text-align: right;
									}
									.elementor-star-rating--align-left .elementor-star-rating__wrapper
									{
										text-align: left;
									}
									.elementor-post-navigation-borders-yes .elementor-post-navigation.elementor-grid
									{
									    margin-top: 10px;
										border-top: 1px solid #d4d4d4;
										border-bottom: 1px solid #d4d4d4;
										padding-top: 15px;
										padding-bottom: 20px;
									}
									.elementor-post-navigation .post-navigation__arrow-wrapper.post-navigation__arrow-prev
									{
										font-size: 15px;
									}
									.elementor-post-navigation .post-navigation__next--label, .elementor-post-navigation .post-navigation__prev--label
									{
										font-size: .8em;
										display: none;
									}
									.elementor-post-navigation .post-navigation__next--title, .elementor-post-navigation .post-navigation__prev--title
									{
										font-size: .7em;
									}
									.elementor-post-navigation .post-navigation__arrow-wrapper.post-navigation__arrow-next
									{
										font-size: 15px;
									}
									.elementor-nav-menu--layout-horizontal li
									{
										float: left;
										width: 96px;
									}
									.elementor-nav-menu--dropdown-tablet .elementor-menu-toggle, .elementor-nav-menu--dropdown-tablet .elementor-nav-menu--dropdown
									{
										display: none;
									}
									.rtwwpge-imggal
									{
										float: left;
										width: 23%;
										padding: 5px;
									}
									.elementor-swiper
									{
										margin-top: 15px;
									}
									.elementor-post-navigation__next.elementor-post-navigation__link
									{
										margin-top: -17px;
										width: 20%;
										float: right;
									}
									.elementor-menu-cart__products
									{
										border-bottom: 1px solid #d4d4d4;
										padding: 25px;
                                    }
									.elementor-menu-cart__product, .elementor-menu-cart__subtotal
									{
										padding-bottom: 10px;
									}
									.elementor-menu-cart__product-name, .elementor-menu-cart__product-price
									{
										font-size: 14px;
										padding-left: 20px;
									}
									.elementor-menu-cart__product-price
									{
										font-weight: bold;
										margin-left: 120px;
										width: 30%;
										margin-top: 90px;
									}
									.elementor-menu-cart__product-name.product-name
									{
										margin-left: 120px;
										width: 30%;
										margin-top: -125px;
									}
									.elementor-menu-cart__product.woocommerce-cart-form__cart-item.cart_item
									{
										width: 100%;
									}
									.elementor-menu-cart__products.woocommerce-mini-cart.cart.woocommerce-cart-form__contents
									{
										min-height: 250px;
									}
									.elementor-menu-cart__product-image.product-thumbnail
									{
										width: 20%;
									}
									.elementor-menu-cart__subtotal
									{
										font-size: 20px;
										text-align: center;
										font-weight: bold;
										padding-top: 20px;
										border-bottom: 1px solid #d4d4d4;
									}
									.elementor-menu-cart__footer-buttons
									{
										text-align: center;
										padding-top: 18px;
										padding-bottom: 2px;
									}
									.elementor-menu-cart__footer-buttons .elementor-button-text
									{
										color: #333333;
									}
									.elementor-menu-cart__footer-buttons .elementor-buttonn
									{
										font-size: 16px;
										padding: 15px 30px;
										border-radius: 4px;
									}
									.elementor-toc__body
									{
										padding: 20px;
									}
									.widget-image-caption.wp-caption-text
									{
										float: left;
										width: 125px;
									}
									.elementor-text-editor.elementor-clearfix
									{
										margin-top: 10px;
									}
									.elementor-widget-image-box.elementor-position-left .elementor-image-box-wrapper
									{
										text-align: left;
									}
									.elementor-widget-image-box.elementor-position-right .elementor-image-box-wrapper
									{
										text-align: right;
									}
									.elementor-social-icons-wrapper
									{
										margin-top: 10px;
										margin-bottom: 10px;
									}
									.menu-item a
									{
										text-decoration: underline;
										color: black;
										font-weight: bold;
									}
									.elementor-heading-title a
									{
										text-decoration: underline;
									}
									.elementor-sitemap-item a
									{
										text-decoration: underline;
									}
									.elementor-sitemap-section
									{
										float: left;
										width: 25%;
									}
									.elementor-icon-list-item a
									{
										text-decoration: underline;
									}
									#comments
									{
										padding-top: 2.617924em;
									}
									#comments .comments-title
									{
										border-bottom: 1px solid rgba(0, 0, 0, 0.05);
										padding-bottom: 0.5407911001em;
									}
									#comments .comment-list
									{
										list-style: none;
										margin-left: 0;
									}
									#comments .comment-list .comment-meta cite
									{
										font-style: normal;
									}
									.comment-list .comment-content, .comment-list #respond
									{
										width: 74.471%;
										float: right;
										margin-right: 0;
										margin-top: -170px;
									}
									#comments .comment-list .comment-content .comment-text
									{
										background-color: #f8f8f8;
									}
									#comments .comment-list .comment-content .comment-text
									{
										padding: 1.618em;
									}
									#comments .comment-list .comment-content .comment-text p
									{
										margin-bottom: 0;
									}
									#comments .comment-list .reply
									{
										margin-bottom: 1.618em;
										padding-top: 0.6180469716em;
									}
									.comment-list .reply 
									{
										text-align: right;
									}
									#comments .comment-list .reply a
									{
										margin-right: 1em;
									}
									.reply a
									{
										text-decoration: underline;
									}
									.cart-collaterals h2
									{
										font-size: 20px;
									}
									.woocommerce-product-gallery.woocommerce-product-gallery--with-images.woocommerce-product-gallery--columns-4.images
									{
										float: left;
										width: 41.1764705882%;
									}
									.single-product div.product .summary
									{
										width: 52.9411764706%;
										float: right;
										margin-right: 0;
									}
									.single-product div.product .images, .single-product div.product .summary, .single-product div.product .woocommerce-product-gallery
									{
										margin-bottom: 2.617924em;
										margin-top: 0;
									}
									.single-product div.product p.price
									{
										font-size: 1.41575em;
										margin: 1.41575em 0;
									}
									form.cart
									{
										margin-bottom: 1.618em;
										padding: 1em 0;
									}
									.single-product div.product form.cart .quantity
									{
										float: left;
										margin-right: 0.875em;
									}
									.quantity .qty
									{
										width: 4.235801032em;
										text-align: center;
									}
									.single-product div.product .product_meta
									{
										font-size: 0.875em;
										padding-top: 1em;
										border-top: 1px solid rgba(0, 0, 0, 0.05);
									}
									.single-product div.product .woocommerce-tabs
									{
										clear: both;
									}
									.woocommerce-tabs
									{
										padding-top: 2.617924em;
										padding-bottom: 2.617924em;
									}
									.woocommerce-tabs ul.tabs
									{
										width: 29.4117647059%;
										float: left;
										margin-right: 5.8823529412%;
									}
									.woocommerce-tabs ul.tabs
									{
										list-style: none;
										margin-left: 0;
										text-align: left;
										border-top: 1px solid 
										rgba(0, 0, 0, 0.05);
									}
									.woocommerce-tabs ul.tabs li 
									{
										border-bottom: 1px solid rgba(0, 0, 0, 0.05);
										padding: 10px;
									}
									.woocommerce-tabs .panel
									{
										width: 64.7058823529%;
										float: right;
									}
									.woocommerce-info, .woocommerce-noreviews, p.no-comments
									{
										background-color: 
										#3d9cd2;
									}
									.woocommerce-message, .woocommerce-info, .woocommerce-error, .woocommerce-noreviews, p.no-comments
									{
										padding: 1em 1.618em;
										margin-bottom: 2.617924em;
										margin-left: 0;
										border-radius: 2px;
										color: #fff;
									    border-left: 0.6180469716em solid rgba(0, 0, 0, 0.15);
									}
									.return-to-shop
									{
										background: none;
										background-color: #eeeeee;
										border-color: #eeeeee;
										padding: 10px;
										width: 100px;
									}
									.button
									{
										color: #333333;
									}
									.form-row-first
									{
										width: 47%;
										float: left;
										margin-right: 5.8823529412%;
									}
									.input-text
									{
										padding: 0.6180469716em;
										background-color: #f2f2f2;
										color: #43454b;
										border: 0;
									}
									.required
									{
									   color: #e2401c;
									}
									.elementor-flip-box__button.elementor-button
									{
										background: transparent;
									}
									.elementor-flip-box__button.elementor-button.elementor-size-sm
									{
										color: #fff;
									}
									.elementor-flip-box__layer__inner .elementor-flip-box__button
									{
									   line-height: 1;
									   padding: 10px 20px;
									   border-radius: 3px;
									   width:60px;
									   font-size: 12px;
									}
									.elementor-cta__button-wrapper .elementor-button
									{
									   line-height: 1;
									   padding: 8px 16px;
									   border-radius: 3px;
									   width:60px;
									   font-size: 12px;
									} 
									.swiper-wrapper
									{
										width: 100%;
										margin-bottom: 20px;
									}
									.elementor-share-btn
									{
										font-size: 10px;
										height: 3.5em;
									}
									.elementor-share-btn__icon
									{
										text-align: center;
									}
									.elementor-share-btn__text
									{
										font-size: 1.5em;
			                            margin-left: 15px;
										margin-top: -20px;
										text-align: center;
										font-weight: bold;
									}
									.elementor-share-btn_facebook
									{
										background-color: #3b5998;
									}
									.elementor-share-btn_twitter
									{
										background-color: #1da1f2;
									}
									.elementor-share-btn_linkedin
									{
										background-color: #0077b5;
									}
									.elementor-share-btn_google
									{
										background-color: #dd4b39;
									}
									.elementor-share-btn_pinterest
									{
										background-color: #bd081c;
									}
									.elementor-share-btn_reddit
									{
										background-color: #ff4500;
									}
									.elementor-share-btn_vk
									{
										background-color: #45668e;
									}
									.elementor-share-btn_odnoklassniki
									{
										background-color: #f4731c;
									}
									.elementor-share-btn_delicious
									{
										background-color: #39f;
									}
									.elementor-share-btn_skype
									{
										background-color: #00aff0;
									}
									.elementor-share-btn_stumbleupon
									{
										background-color: #eb4924;
									}
									.elementor-share-btn_telegram
									{
										background-color: #2ca5e0;
									}
									.elementor-share-btn_pocket
									{
										background-color: #ef3f56;
									}
									.elementor-share-btn_xing
									{
										background-color: #026466;
									}
									.elementor-share-btn_whatsapp
									{
										background-color: #25d366;
									}
									.elementor-share-btn_email
									{
										background-color: #ea4335;
									}
									.elementor-share-btn_print
									{
										background-color: #aaa;
									}
									.elementor-share-buttons--skin-gradient .elementor-share-btn
									{
										color: #fff;
									}
									.elementor-social-icons-wrapper .elementor-screen-only
									{
										display: none;
									}
									.elementor-share-btn_digg
									{
										background-color: #005be2;
									}
									.elementor-slides .swiper-slide-inner .elementor-slide-button
									{
										border: 2px solid #fff;
									}
									.elementor-position-right .elementor-image-box-content
									{
										margin-right: 180px;
										margin-top: -200px;
										margin-bottom: 150px;
									}
									.elementor-position-left .elementor-image-box-content
									{
										margin-left: 180px;
										margin-top: -200px;
										margin-bottom: 150px;
									}
									.elementor-position-left .elementor-icon-box-content
									{
										margin-left: 80px;
										margin-top: -80px;
										margin-bottom: 50px;
									}
									.elementor-position-right .elementor-icon-box-content
									{
										margin-right: 80px;
										margin-top: -80px;
										margin-bottom: 50px;
									}
									.elementor-ribbon
									{
										width: 20%;
										float: right;
										margin-top: -195px;
										margin-bottom: 170px;
									}
									.elementor-ribbon-inner
									{
										text-align: center;
										font-size: 12px;
										background: #000;
										color: white;
										line-height: 2;
									}
									.elementor-align-left
									{
										text-align: left;
									}
									.elementor-align-center
									{
										text-align: center;
									}
									.elementor-align-right
									{
										text-align: right;
									}
									.elementor-align-right .elementor-button 
									{
										width: 55px;
										float: right;
									}
									.elementor-align-center .elementor-button
									{
										margin-left: 43%;
									}
									.widget_shopping_cart_content
									{
										box-shadow: 0 0 8px gray;
									}
									.elementor-widget-share-buttons .elementor-grid
									{
										margin-top: 10px;
									}
									.elementor-widget-wp-widget-recent-posts h5
									{
										font-size: 20px;
										font-weight: bold;
										color: #db0c46;
									}
									.elementor-widget-wp-widget-recent-posts li
									{
										list-style-type: none;
										padding: 5px;
									}
									.elementor-widget-wp-widget-recent-posts li a
									{
										color: #222;
										font-size: 15px;
										border-bottom: 1px solid gray;
										padding: 0.3em 0;
									}
									.elementor-widget-wp-widget-calendar h5
									{
										font-size: 20px;
										font-weight: bold;
										text-align: center;
									}
									.elementor-widget-wp-widget-categories h5
									{
										font-weight: bold;
										font-size: 20px;
										color: green;
									}
									.elementor-widget-wp-widget-categories li
									{
										list-style-type: none;
									}
									.elementor-widget-wp-widget-categories li a
									{
										color: #222;
										font-size: 15px;
										border-bottom: 1px solid gray;
										padding: 0.3em 0;
									}
									.elementor-widget-wp-widget-pages h5
									{
										font-weight: bold;
										font-size: 20px;
										color: purple;
									}
									.elementor-widget-wp-widget-pages li
									{
										list-style-type: none;
										padding: 5px;
									}
									.elementor-widget-wp-widget-pages li a
									{
										color: #222;
										font-size: 15px;
										border-bottom: 1px solid gray;
										padding: 0.3em 0;
									}
									.elementor-widget-wp-widget-woocommerce_products h5
									{
										font-weight: bold;
										font-size: 20px;
									}
									.elementor-widget-wp-widget-nav_menu h5
									{
										font-weight: bold;
										font-size: 20px;
									}
									.elementor-widget-wp-widget-nav_menu li
									{
										list-style-type: none;
										padding: 5px;
									}
									.elementor-widget-wp-widget-woocommerce_top_rated_products h5
									{
										font-weight: bold;
										font-size: 20px;
									}
									.elementor-widget-wp-widget-woocommerce_widget_cart h5
									{
										font-weight: bold;
										font-size: 18px;
									}
									.product-title
								   {
									font-size: 12px;
									font-weight: bold;
									width: 150px;
									margin-top: -55px;
								   }
								   .elementor-widget-wp-widget-media_gallery h5
								   {
									   font-size: 18px;
									   font-weight: bold;
									   color: #06a9ec;
								   }
			';
			
			if ( isset($this->rtwwpge_stng ['rtwwpge_pdf_css']) && !empty($this->rtwwpge_stng ['rtwwpge_pdf_css']) )
			{
				$rtwwpge_postcss_content .= $this->rtwwpge_stng ['rtwwpge_pdf_css'];
			}
			$rtwwpge_postcss_content .= '</style>';
			/* PDF Custom CSS End */
			
			/*Display Post Title*/
			if (!isset ( $this->rtwwpge_stng ['rtwwpge_hide_title'] )) 
			{
				$rtwwpge_pdf_html .= '<h2 class="rtwwpge_pdf_title" style="text-align:center;margin:0px;padding:0px;margin-bottom:8px">'.apply_filters ( 'rtw_post_title', $rtwwpge_pdf_title, get_the_ID() ).'</h2>';
			}

			/*Display Post Category*/
			if (isset ( $this->rtwwpge_stng ['rtwwpge_post_category'] )) 
			{
				$rtwwpge_cat = get_the_category ( $post->ID );
				if( $rtwwpge_cat ) 
				{
					$rtwwpge_pdf_html .= '<p class="rtwwpge_pdf_categories"><strong>'.esc_html_e('Categories : ', 'rtwwpge-wordpress-pdf-generator-for-elementor').'</strong>' . esc_html_e($rtwwpge_cat [0]->rtwwpge_cat_name) . '</p>';
				}
			}
			/*End Display Post Category*/
			
			/*Display tags*/
			if( isset($this->rtwwpge_stng ['rtwwpge_post_tag'] ) ) 
			{
				$rtwwpge_tags = get_the_tags ( $post->the_tags );
				if ($rtwwpge_tags) 
				{
					$rtwwpge_pdf_html .= '<p class="rtwwpge_pdf_tags"><strong>Tagged as : </strong>';
					foreach ( $rtwwpge_tags as $tag ) 
					{
						$rtwwpge_tag_link = get_tag_link ( $tag->rtwwpge_term_id );
						$rtwwpge_pdf_html .= '<a href="' . $rtwwpge_tag_link . '">' . $tag->name . '</a>';
						if (next ( $rtwwpge_tags )) 
						{
							$rtwwpge_pdf_html .= ', ';
						}
					}
					$rtwwpge_pdf_html .= '</p>';
				}
			}
			/*End Display tags*/
			
			/*Display Date*/
			if( isset( $this->rtwwpge_stng ['rtwwpge_post_date'] ) )
			{
				$rtwwpge_date = date ( "d-m-Y", strtotime ( $post->rtwwpge_post_date ) );
				$rtwwpge_pdf_html .= '<p class="rtwwpge_pdf_date"><strong>Date : </strong>' . $rtwwpge_date . '</p>';
			}
			$rtwwpge_pdf_html = apply_filters('html_after_date',$rtwwpge_pdf_html, get_the_ID() );
			/* End Display Date*/
			
			/*Featured Image*/
			if( isset( $this->rtwwpge_stng ['rtwwpge_featured_img'] ) ) 
			{
				if( has_post_thumbnail ( get_the_ID() ) ) 
				{
					// $rtwwpge_pdf_html .= get_the_post_thumbnail ( get_the_ID() );
					$rtwwpge_pdf_html .= '<div id="rtwwpge_featured_image" style="padding:0px; margin:0px; text-align:center;">'.get_the_post_thumbnail ( get_the_ID() ).'</div>';
				}
			}
			/*End Featured Image*/

			$rtwwpge_post_content = apply_filters ( 'the_post_export_content', $rtwwpge_post_content, get_the_ID() );
			$rtwwpge_pdf_html .= htmlspecialchars_decode ( htmlentities ( $rtwwpge_post_content, ENT_NOQUOTES, 'UTF-8', false ), ENT_NOQUOTES );
			$rtwwpge_pdf_html .="</body>";

			/*PDF Page Size*/
			if( isset( $this->rtwwpge_stng ['rtwwpge_pdf_page_size'] ) && $this->rtwwpge_stng ['rtwwpge_pdf_page_size'] != 'Select' ) 
			{
				$rtwwpge_page_size = $this->rtwwpge_stng ['rtwwpge_pdf_page_size'];
			} 
			else 
			{
				$rtwwpge_page_size = serialize(array(210,297));
			}
			/*End PDF Page Size*/

			/*PDF Page Orientation*/
			if( isset( $this->rtwwpge_stng ['rtwwpge_page_orien'] ) ) 
			{
				$rtwwpge_page_orientation = $this->rtwwpge_stng ['rtwwpge_page_orien'];
			
			} 
			else 
			{
				$rtwwpge_page_orientation = 'P';
			}
			/*End PDF Page Orientation*/

			/*PDF left margin*/
			if( isset( $this->rtwwpge_stng['rtwwpge_body_left_margin'] ) && !empty( $this->rtwwpge_stng ['rtwwpge_body_left_margin'] ) )
			{
				$rtwwpge_lft_marg = $this->rtwwpge_stng ['rtwwpge_body_left_margin'];	
			} 
			else 
			{
				$rtwwpge_lft_marg = 15;
			}

			/*PDF right margin*/
			if( isset( $this->rtwwpge_stng['rtwwpge_body_right_margin'] ) && !empty( $this->rtwwpge_stng ['rtwwpge_body_right_margin'] ) )
			{
				$rtwwpge_rgt_marg = $this->rtwwpge_stng ['rtwwpge_body_right_margin'];	
			} 
			else 
			{
				$rtwwpge_rgt_marg = 15;
			}

			/*PDF top margin*/
			if( isset( $this->rtwwpge_stng['body_top_margin'] ) && !empty( $this->rtwwpge_stng ['body_top_margin'] ) )
			{
				$rtwwpge_top_marg = $this->rtwwpge_stng ['body_top_margin'];	
			} 
			else 
			{
				$rtwwpge_top_marg = 15;
			}

			/*PDF header top margin*/
			if( isset( $this->rtwwpge_stng['rtwwpge_header_top_margin'] ) && !empty( $this->rtwwpge_stng ['rtwwpge_header_top_margin'] ) )
			{
				$rtwwpge_hdr_top_marg = $this->rtwwpge_stng ['rtwwpge_header_top_margin'];	
			} 
			else 
			{
				$rtwwpge_hdr_top_marg = 7;
			}

			/*PDF footer top margin*/
			if( isset( $this->rtwwpge_stng['rtwwpge_footer_top_margin'] ) && !empty( $this->rtwwpge_stng ['rtwwpge_footer_top_margin'] ) )
			{
				$rtwwpge_foo_top_marg = $this->rtwwpge_stng ['rtwwpge_footer_top_margin'];	
			} 
			else 
			{
				$rtwwpge_foo_top_marg = 15;
			}

			if( isset($this->rtwwpge_stng['rtwwpge_body_font_family']) && !empty($this->rtwwpge_stng['rtwwpge_body_font_family']) )
			{
				$rtwwpge_body_font_family = $this->rtwwpge_stng['rtwwpge_body_font_family'];
			}
			else
			{
				$rtwwpge_body_font_family = "dejavusanscondensed";
			}

			if(isset($this->rtwwpge_stng['rtwwpge_body_font_size']) && !empty( $this->rtwwpge_stng['rtwwpge_body_font_size'] ) )
			{
				$rtwwpge_body_font_size = $this->rtwwpge_stng ['rtwwpge_body_font_size'];
			}
			else
			{
				$rtwwpge_body_font_size = 10;
			}

			include(RTWWPGE_DIR ."includes/mpdf/autoload.php");

			$rtwwpge_mpdf = new \Mpdf\Mpdf( ['mode' => 'utf-8', 'format' => unserialize( $rtwwpge_page_size ), 'default_font_size' => $rtwwpge_body_font_size, 'default_font' => $rtwwpge_body_font_family, 'margin_left' => $rtwwpge_lft_marg, 'margin_right' => $rtwwpge_rgt_marg, 'margin_top' => $rtwwpge_top_marg, 'margin_bottom' => '20', 'margin_header' => $rtwwpge_hdr_top_marg, 'margin_footer' => $rtwwpge_foo_top_marg, 'orientation' => $rtwwpge_page_orientation ]);
			
			$rtwwpge_mpdf->setAutoTopMargin = 'stretch';
			$rtwwpge_mpdf->setAutoBottomMargin = 'stretch';
			$rtwwpge_mpdf->SetDisplayMode('fullpage');
			
			if( isset( $this->rtwwpge_stng['rtwwpge_header_font_size'] ) && !empty( $this->rtwwpge_stng['rtwwpge_header_font_size'] ) ) 
			{
				$rtwwpge_hdr_font_size = $this->rtwwpge_stng ['rtwwpge_header_font_size'];
			} 
			else 
			{
				$rtwwpge_hdr_font_size = 15;
			}

			if( isset( $this->rtwwpge_stng['rtwwpge_header_font_family'] ) && !empty( $this->rtwwpge_stng['rtwwpge_header_font_family'] ) )
			{
				$rtwwpge_hdr_family = $this->rtwwpge_stng['rtwwpge_header_font_family'];
			}
			else
			{
				$rtwwpge_hdr_family = 'sans-serif';
			}

			if( isset( $this->rtwwpge_stng['rtwwpge_footer_font_family'] ) && !empty( $this->rtwwpge_stng['rtwwpge_footer_font_family'] ) )
			{
				$rtwwpge_foo_family = $this->rtwwpge_stng['rtwwpge_footer_font_family'];
			}
			else
			{
				$rtwwpge_foo_family = 'sans-serif';
			}
			$rtwwpge_mpdf->defaultheaderfontsize = $rtwwpge_hdr_font_size;
			$rtwwpge_mpdf->defaultheaderline = 1; 	/* 1 to include line below header/above footer */

			$rtwwpge_site_name=get_bloginfo ( 'name' );
			$rtwwpge_site_desc=get_bloginfo ( 'description' );
			$rtwwpge_site_url=home_url();

			if( isset($this->rtwwpge_stng['rtwwpge_remove_header']) && $this->rtwwpge_stng['rtwwpge_remove_header'] == 1 )
			{
				$rtwwpge_mpdf->SetHTMLHeader('', 'O' );
				$rtwwpge_mpdf->SetHTMLHeader('', 'E');
			}
			else
			{
				$rtwwpge_header_bb = 'border-bottom: 2px solid #000000;';
				/* Hide Header Horizontal Line */
				if ( isset($this->rtwwpge_stng['rtwwpge_header_bb']) && $this->rtwwpge_stng['rtwwpge_header_bb'] == 1 ) {
					$rtwwpge_header_bb = '';
				}

				if( isset($this->rtwwpge_stng['rtwwpge_header_html']) && !empty($this->rtwwpge_stng['rtwwpge_header_html']) )
				{
					$rtwwpge_mpdf->SetHTMLHeader('<div style="'.$rtwwpge_header_bb.'padding-bottom:12px; font-family:'.$rtwwpge_hdr_family.';">'.$this->rtwwpge_stng['rtwwpge_header_html'].'</div>', 'O' );
					$rtwwpge_mpdf->SetHTMLHeader('<div style="'.$rtwwpge_header_bb.'padding-bottom:12px; font-family:'.$rtwwpge_hdr_family.';">'.$this->rtwwpge_stng['rtwwpge_header_html'].'</div>', 'E');
				}
				else
				{
					$rtwwpge_mpdf->SetHTMLHeader('<div style="width:100%;height:70px;'.$rtwwpge_header_bb.'"><div style="float:left;font-size:'.$rtwwpge_hdr_font_size.'px;font-family:'.$rtwwpge_hdr_family.';"><h2 style="margin:0px;padding:0px;">'.$rtwwpge_site_name.'</h2><p style="margin:0px;padding:0px;">'.$rtwwpge_site_desc.'</p><p style="margin:0px;padding:0px;">'.$rtwwpge_site_url.'</p></div></div>','O');
					$rtwwpge_mpdf->SetHTMLHeader('<div style="width:100%;height:70px;'.$rtwwpge_header_bb.'"><div style="float:left;font-size:'.$rtwwpge_hdr_font_size.'px;font-family:'.$rtwwpge_hdr_family.';"><h2 style="margin:0px;padding:0px;">'.$rtwwpge_site_name.'</h2><p style="margin:0px;padding:0px;">'.$rtwwpge_site_desc.'</p><p style="margin:0px;padding:0px;">'.$rtwwpge_site_url.'</p></div></div>','E');
				}
		    }

			if( isset($this->rtwwpge_stng['rtwwpge_footer_font_size']) && !empty($this->rtwwpge_stng['rtwwpge_footer_font_size']) ) 
			{
				$rtwwpge_foo_font_size = $this->rtwwpge_stng ['rtwwpge_footer_font_size'];
			} 
			else 
			{
				$rtwwpge_foo_font_size = 10;
			}
			$rtwwpge_mpdf->defaultfooterfontsize = $rtwwpge_foo_font_size;	/* in pts */
			$rtwwpge_mpdf->defaultfooterline = 1; 	/* 1 to include line below header/above footer */
			
			/* Footer */
			if( isset($this->rtwwpge_stng['rtwwpge_remove_footer']) && $this->rtwwpge_stng['rtwwpge_remove_footer'] == 1 )
			{
				$rtwwpge_mpdf->SetHTMLFooter( '', 'O' );
				$rtwwpge_mpdf->SetHTMLFooter( '', 'E' );
			}	
			else
			{
				/* Hide Footer Horizontal Line */
				$rtwwpge_footer_tb = 'border-top: 2px solid #000000;';
				if ( isset($this->rtwwpge_stng['rtwwpge_footer_tb']) && $this->rtwwpge_stng['rtwwpge_footer_tb'] == 1 ) {
					$rtwwpge_footer_tb = '';
				}
				
				if( isset($this->rtwwpge_stng['rtwwpge_footer_html']) && !empty( $this->rtwwpge_stng['rtwwpge_footer_html'] ) )
				{
					$rtwwpge_footer_txt = $this->rtwwpge_stng['rtwwpge_footer_html'];
				}
				else
				{
					$rtwwpge_footer_txt = '';
				}

				/* Hide Page Number */
				if (isset($this->rtwwpge_stng['rtwwpge_hide_pageno']) && !empty( $this->rtwwpge_stng['rtwwpge_hide_pageno'] ))
				{					
					$rtwwpge_mpdf->SetHTMLFooter( '<div style="width:100%;margin:0px;padding:0px;margin-top:2px;padding-top:10px;'.$rtwwpge_footer_tb.'font-family:'.$rtwwpge_foo_family.';"><div style="width: 100%;margin:0px;padding:0px;float: left;">'.$rtwwpge_footer_txt.'</div>', 'O' );
					$rtwwpge_mpdf->SetHTMLFooter( '<div style="width:100%;margin:0px;padding:0px;margin-top:2px;padding-top:10px;'.$rtwwpge_footer_tb.'font-family:'.$rtwwpge_foo_family.';"><div style="width: 100%;margin:0px;padding:0px;float: left;">'.$rtwwpge_footer_txt.'</div>', 'E' );
				}
				else
				{
					$rtwwpge_page_no = '{PAGENO}/{nbpg}';

					$rtwwpge_mpdf->SetHTMLFooter( '<div style="width:100%;margin:0px;padding:0px;margin-top:2px;padding-top:10px;'.$rtwwpge_footer_tb.'font-family:'.$rtwwpge_foo_family.';"><div style="width: 92%;margin:0px;padding:0px;float: left;">'.$rtwwpge_footer_txt.'</div><div style="width: 8%;margin:0px;padding:0px;float: right;text-align:right;">'.$rtwwpge_page_no.'</div>', 'O' );
					$rtwwpge_mpdf->SetHTMLFooter( '<div style="width:100%;margin:0px;padding:0px;margin-top:2px;padding-top:10px;'.$rtwwpge_footer_tb.'font-family:'.$rtwwpge_foo_family.';"><div style="width: 92%;margin:0px;padding:0px;float: left;">'.$rtwwpge_footer_txt.'</div><div style="width: 8%;margin:0px;padding:0px;float: right;text-align:right;">'.$rtwwpge_page_no.'</div>', 'E' );
				}
			}
			
			/* WATERMARK */
			if( isset($this->rtwwpge_stng ['rtwwpge_enable_text_watermark'] ) )
			{
				if( isset($this->rtwwpge_stng ['rtwwpge_watermark_text'] ) && !empty( $this->rtwwpge_stng ['rtwwpge_watermark_text'] ) )
				{  
				    $rtwwpge_alpha=0.2;
					if( isset( $this->rtwwpge_stng['rtwwpge_watermark_text_trans'] ) && !empty($this->rtwwpge_stng['rtwwpge_watermark_text_trans'] ) )
					{
						$rtwwpge_alpha = $this->rtwwpge_stng['rtwwpge_watermark_text_trans'];
					}
					
					if( isset($this->rtwwpge_stng['rtwwpge_watermark_rotation']) && !empty($this->rtwwpge_stng['rtwwpge_rotate_water']))
					{
						$GLOBALS['rotate'] = $this->rtwwpge_stng['rtwwpge_watermark_rotation'];
					}
					$rtwwpge_mpdf->SetWatermarkText( trim($this->rtwwpge_stng ['rtwwpge_watermark_text']),$rtwwpge_alpha );
				    $rtwwpge_mpdf->showWatermarkText = true;
				    if( isset( $this->rtwwpge_stng['rtwwpge_watermark_font'] ) && !empty( $this->rtwwpge_stng['rtwwpge_watermark_font'] ) )
					{
						$rtwwpge_mpdf->watermark_font = $this->rtwwpge_stng['rtwwpge_watermark_font'];
					}
				}
				
			}
			
			if( isset( $this->rtwwpge_stng ['rtwwpge_enable_image_watermark'] ) )
			{
				if( isset( $this->rtwwpge_stng ['rtwwpge_watermark_img_url'] ) && !empty($this->rtwwpge_stng ['rtwwpge_watermark_img_url']) )
				{
					$rtwwpge_alpha = 0.2;
					if( isset( $this->rtwwpge_stng['rtwwpge_watermark_image_trans'] ) && !empty($this->rtwwpge_stng['rtwwpge_watermark_image_trans']) )
					{
						$rtwwpge_alpha = $this->rtwwpge_stng['rtwwpge_watermark_image_trans'];
					}
					$rtwwpge_watermark_img_dim ='D';
					if( isset($this->rtwwpge_stng['rtwwpge_watermark_img_dim']) && $this->rtwwpge_stng['rtwwpge_watermark_img_dim'] == 'P') 
					{
	                 	$rtwwpge_watermark_img_dim = 'P';
					}
					if(isset($this->rtwwpge_stng['rtwwpge_watermark_img_dim']) && $this->rtwwpge_stng['rtwwpge_watermark_img_dim']=='F')
					{
	                 	$rtwwpge_watermark_img_dim = 'F';
					}
					if(isset($this->rtwwpge_stng['rtwwpge_watermark_img_dim']) && $this->rtwwpge_stng['rtwwpge_watermark_img_dim']=='INT')
					{
	                 	$rtwwpge_watermark_img_dim = $this->rtwwpge_stng['rtwwpge_water_img_dim_int'];
	                 	$rtwwpge_watermark_img_dim = (int)$rtwwpge_watermark_img_dim ; 
					}
					if(isset($this->rtwwpge_stng['rtwwpge_watermark_img_dim']) && $this->rtwwpge_stng['rtwwpge_watermark_img_dim']=='array')
					{
	                 	$rtwwpge_watermark_img_dim = array($this->rtwwpge_stng['rtwwpge_water_img_dim_width'],$this->rtwwpge_stng['rtwwpge_water_img_dim_height']);
					}
					$rtwwpge_watermark_pos = 'P';
					if(isset($this->rtwwpge_stng['rtwwpge_watermark_img_pos']) && $this->rtwwpge_stng['rtwwpge_watermark_img_pos']=='F')
					{
						$rtwwpge_watermark_pos='F';	
					}
					if(isset($this->rtwwpge_stng['rtwwpge_watermark_img_pos']) && $this->rtwwpge_stng['rtwwpge_watermark_img_pos']=='arrays')
					{
						$rtwwpge_watermark_pos=array($this->rtwwpge_stng['rtwwpge_watermark_img_pos_x'],$this->rtwwpge_stng['rtwwpge_watermark_img_pos_y']);
					}
					$rtwwpge_mpdf->SetWatermarkImage($this->rtwwpge_stng ['rtwwpge_watermark_img_url'],$rtwwpge_alpha,$rtwwpge_watermark_img_dim ,$rtwwpge_watermark_pos);
					$rtwwpge_mpdf->showWatermarkImage = true;
				}	
			}

			/* Right-to-Left (RTL) Language Text Alignment */
			if( isset($this->rtwwpge_stng['rtwwpge_rtl_support']) && $this->rtwwpge_stng['rtwwpge_rtl_support'] == 1)
			{
				$rtwwpge_mpdf->SetDirectionality('rtl');
			}
			else
			{
				$rtwwpge_mpdf->SetDirectionality('ltr');
			}
			if (isset($_SERVER['HTTP_X_GT_LANG']) && $_SERVER['HTTP_X_GT_LANG'] == 'ar') {
				$rtwwpge_mpdf->SetDirectionality('rtl');
			}

			// $rtwwpge_pdf_html = preg_replace('/<img[^>]+\>/i', '<div style="padding:5px">$0 </div><br>', $rtwwpge_pdf_html);
			$rtwwpge_mpdf->SetDefaultBodyCSS( 'background-color', $this->rtwwpge_stng['rtwwpge_back_color']);
			$rtwwpge_mpdf->SetDefaultBodyCSS('background', "url(".$this->rtwwpge_stng['rtwwpge_bck_img'].")");
			$rtwwpge_mpdf->SetDefaultBodyCSS('background-image-resize', 6);

			/* PDF Security Start*/
			if( isset($this->rtwwpge_stng['rtwwpge_pass_protection']) && !empty($this->rtwwpge_stng['rtwwpge_pass_protection']) ) 
			{
				if( isset($this->rtwwpge_stng['rtwwpge_admin_pass']) && !empty($this->rtwwpge_stng['rtwwpge_admin_pass']) ) {
					$rtwwpge_admin_secure = $this->rtwwpge_stng['rtwwpge_admin_pass'];
				}
				else {
					$rtwwpge_admin_secure = 12345678;
				}

				if ( is_user_logged_in() ) {
					$rtwwpge_current_user = wp_get_current_user();
					$rtwwpge_name = $rtwwpge_current_user->user_login;
					$rtwwpge_email = $rtwwpge_current_user->user_email;
					if (isset( $this->rtwwpge_stng['protctn_type_name'] ) && $this->rtwwpge_stng['protctn_type_name'] == 1)
					{
						$rtwwpge_user_secure = $rtwwpge_name;
					}
					else if (isset( $this->rtwwpge_stng['protctn_type_name'] ) && $this->rtwwpge_stng['protctn_type_name'] == 2)
					{
						$rtwwpge_user_secure = $rtwwpge_email;
					}
					else
					{
						$rtwwpge_user_secure = (substr($rtwwpge_name, 0, 4).substr($rtwwpge_email, 0, 4));
					}
				}
				else {
					if( isset($this->rtwwpge_stng['rtwwpge_guestuser_pass']) && !empty($this->rtwwpge_stng['rtwwpge_guestuser_pass']) ) {
						$rtwwpge_user_secure = $this->rtwwpge_stng['rtwwpge_guestuser_pass'];
					}
				}				
			}

			if( isset($this->rtwwpge_stng['rtwwpge_other_pdf_security']) && !empty($this->rtwwpge_stng['rtwwpge_other_pdf_security']) )
			{
				if( isset($this->rtwwpge_stng['disable_perm_copy']) && !empty($this->rtwwpge_stng['disable_perm_copy']) ) {
					$rtwwpge_disable_perm_copy = 'copy';
				}
				if( isset($this->rtwwpge_stng['disable_perm_print']) && !empty($this->rtwwpge_stng['disable_perm_print']) ) {
					$rtwwpge_disable_perm_print = 'print';
				}
				if( isset($this->rtwwpge_stng['disable_perm_modify']) && !empty($this->rtwwpge_stng['disable_perm_modify']) ) {
					$rtwwpge_disable_perm_modify = 'modify';
				}
				if( isset($this->rtwwpge_stng['disable_perm_annot']) && !empty($this->rtwwpge_stng['disable_perm_annot']) ) {
					$rtwwpge_disable_perm_annot = 'annot-forms';
				}
				if( isset($this->rtwwpge_stng['disable_perm_fill']) && !empty($this->rtwwpge_stng['disable_perm_fill']) ) {
					$rtwwpge_disable_perm_fill = 'fill-forms';
				}
				if( isset($this->rtwwpge_stng['disable_perm_extract']) && !empty($this->rtwwpge_stng['disable_perm_extract']) ) {
					$rtwwpge_disable_perm_extract = 'extract';
				}
				if( isset($this->rtwwpge_stng['disable_perm_assemble']) && !empty($this->rtwwpge_stng['disable_perm_assemble']) ) {
					$rtwwpge_disable_perm_assemble = 'assemble';
				}

				$all_permis = array('copy','print','modify','annot-forms','fill-forms','extract','assemble');
				$disable_permis = array( $rtwwpge_disable_perm_copy, $rtwwpge_disable_perm_print, $rtwwpge_disable_perm_modify, $rtwwpge_disable_perm_annot, $rtwwpge_disable_perm_fill, $rtwwpge_disable_perm_extract, $rtwwpge_disable_perm_assemble );

				foreach ($disable_permis as $key => $value)
				{
					$pos = array_search($value, $all_permis);
					unset($all_permis[$pos]);
				}
				$all_permis = array_values($all_permis);
			}

			$rtwwpge_mpdf->SetProtection( $all_permis, $rtwwpge_user_secure, $rtwwpge_admin_secure );
			/* PDF Security End*/

			// for simple html dom
			$rtwwpge_dom_obj = new simple_html_dom();
			 
			/*Change the html of elementor-tabs*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_tab_html = '';
			foreach ($rtwwpge_dom_obj->find('.elementor-tabs') as $element)
			{
				foreach ($element->find('.elementor-tabs-wrapper .elementor-tab-title') as $value)
				{
				    $rtwwpge_tab_html .= '<div class="elementor-tabs" role="tablist">
											<div class="elementor-tabs-wrapper"> 									
												'.$value->outertext.'				
											</div>';
                                            foreach ($rtwwpge_dom_obj->find('#'.$value->getAttribute('aria-controls')) as $val) 
							                {
												$rtwwpge_tab_html .= '<div class="elementor-tabs-content-wrapper">'.$val->outertext.'</div>';
							                }
					$rtwwpge_tab_html .= '</div>';
				}
				$element->outertext = $rtwwpge_tab_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the html of elementor-image-carousel-wrapper*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_img_html = '';
			foreach($rtwwpge_dom_obj->find('.elementor-image-carousel-wrapper') as $image)
			{
				foreach ($image->find('.swiper-slide-image') as $value)
				{
                    $rtwwpge_img_html .= $value->outertext;
                }
				$image->outertext = $rtwwpge_img_html;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the html of elementor-portfolio*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_portimg_html = '';
			foreach($rtwwpge_dom_obj->find('.elementor-portfolio') as $img)
			{
				foreach($img->find('.elementor-post__thumbnail__link') as $element)
				{
					foreach ($element->find('.elementor-portfolio-item__img img') as $values)
					{
                          $rtwwpge_portimg_html .= '<div class="rtwwpge-grid-container">'.$values->outertext;
					}
						foreach($element->find('.elementor-portfolio-item__title') as $text)
						{
						    $rtwwpge_portimg_html .= '<div class="rtwwpge-post-title">'.$text->innertext.'</div></div>';
					    }
				}
			    $img->outertext = $rtwwpge_portimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.rtwwpge-grid-container img') as $pval)
			{
				$pval->width=null;
				$pval->height=null;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.elementor-post__avatar img') as $pval)
			{
				$pval->width=50;
				$pval->height=50;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.elementor-author-box__avatar img') as $avtval)
			{
				$avtval->width=80;
				$avtval->height=80;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.elementor-testimonial-image img') as $testval)
			{
				$testval->width=50;
				$testval->height=50;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.elementor-post__thumbnail img') as $ttval)
			{
				$ttval->width=null;
				$ttval->height=null;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.storefront-product-pagination img') as $navval)
			{
				$navval->width=50;
				$navval->height=50;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
            $rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.elementor-testimonial__footer img') as $footimg)
			{
				$footimg->width=50;
				$footimg->height=50;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.elementor-testimonial__image img') as $timg)
			{
				$timg->width=36;
				$timg->height=36;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.product-thumbnail img') as $wimg)
			{
				$wimg->width=32;
				$wimg->height=32;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
		
			/*get the value of aria-valuenow of progress wrapper*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_percent_html = '';
			$rtwwpge_per_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-progress-wrapper') as $val)
			{
			    $rtwwpge_percent_html =$val->getAttribute('aria-valuenow');
					foreach($val->find('.elementor-progress-bar') as $per)
					{
						$rtwwpge_per_html =$per->setAttribute('style','width:'.$rtwwpge_percent_html.'%');
					}
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the a of calendar wrap in span*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_calendar_html = '';
            foreach($rtwwpge_dom_obj->find('.calendar_wrap a') as $calval)
			{
				$rtwwpge_calendar_html =$calval->innertext;
				$calval->outertext ='<span>'.$rtwwpge_calendar_html.'</span>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-price-list-separator in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_changespan_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-list-header .elementor-price-list-separator') as $calval)
			{
				$rtwwpge_changespan_html =$calval->innertext;
				$calval->outertext ='<div class="elementor-price-list-separator">'.$rtwwpge_changespan_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
		
			/*Change the span of elementor-progress-percentage in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_progressbar_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-progress-wrapper .elementor-progress-percentage') as $calval)
			{
				$rtwwpge_progressbar_html =$calval->innertext;
				$calval->outertext ='<div class="elementor-progress-percentage">'.$rtwwpge_progressbar_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-progress-text in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_progressbar_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-progress-wrapper .elementor-progress-text') as $progval)
			{
				$rtwwpge_progress_html =$progval->innertext;
				$progval->outertext ='<div class="elementor-progress-text">'.$rtwwpge_progress_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*Change the span of elementor-price-list-price in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_changespan_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-list-header .elementor-price-list-price') as $calval)
			{
				$rtwwpge_changespan_html =$calval->innertext;
				$calval->outertext ='<div class="elementor-price-list-price">'.$rtwwpge_changespan_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-testimonial__title in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_changecite_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-testimonial__cite .elementor-testimonial__title') as $calval)
			{
				$rtwwpge_changecite_html =$calval->innertext;
				$calval->outertext ='<div class="elementor-testimonial__title">'.$rtwwpge_changecite_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-countdown-digits in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_changecount_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-countdown-item .elementor-countdown-digits') as $calval)
			{
				$rtwwpge_changecount_html =$calval->innertext;
				$calval->outertext ='<div class="elementor-countdown-digits elementor-countdown-days">'.$rtwwpge_changecount_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-price-table__fractional-part in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pricetable_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__after-price .elementor-price-table__fractional-part') as $fracval)
			{
				$rtwwpge_pricetable_html =$fracval->innertext;
				$fracval->outertext ='<div class="elementor-price-table__fractional-part">'.$rtwwpge_pricetable_html.'</div>';
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-typo-excluded in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_priceperiod_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__period') as $prdval)
			{
				$rtwwpge_priceperiod_html =$prdval->innertext;
				$prdval->outertext ='<div class="elementor-price-table__period elementor-typo-excluded">'.$rtwwpge_priceperiod_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-price-table__currency in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pricecurr_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__price .elementor-price-table__currency') as $cval)
			{
				$rtwwpge_pricecurr_html =$cval->innertext;
				$cval->outertext ='<div class="elementor-price-table__currency elementor-currency--before">'.$rtwwpge_pricecurr_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Change the span of elementor-price-table__integer-part in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_priceinteger_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__price .elementor-price-table__integer-part') as $intval)
			{
				$rtwwpge_priceinteger_html =$intval->innertext;
				$intval->outertext ='<div class="elementor-price-table__integer-part">'.$rtwwpge_priceinteger_html.'</div>';
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*Change the span of woocommerce-Price-amount amount in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_spandiv_html = '';
            foreach($rtwwpge_dom_obj->find('.woocommerce-LoopProduct-link .woocommerce-Price-amount') as $sdiv)
			{
				$rtwwpge_spandiv_html =$sdiv->innertext;
				$sdiv->outertext ='<div class="woocommerce-Price-amount amount">'.$rtwwpge_spandiv_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*Change the span of elementor-divider-separator in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_divider_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-divider .elementor-divider-separator') as $div)
			{
				$rtwwpge_divider_html =$div->innertext;
				$div->outertext ='<div class="elementor-divider-separator">'.$rtwwpge_divider_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.woocommerce-LoopProduct-link .attachment-woocommerce_thumbnail') as $ppimg)
			{
				$ppimg->width=50;
				$ppimg->height=50;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.product_list_widget img') as $pprimg)
			{
				$pprimg->width=50;
				$pprimg->height=50;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.woocommerce-LoopProduct-link .woocommerce-placeholder.wp-post-image') as $ppimg)
			{
				$ppimg->width=50;
				$ppimg->height=50;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*Working of Star rating for product*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_star_html = '';
            foreach($rtwwpge_dom_obj->find('.rating') as $starrating)
			{
				$rtwwpge_star_html = $starrating->innertext;
				$rtwwpge_starreview_html = '<span style="color: #fdcc0d; font-size: 25px;">★</span>';
                for( $i = 1; $i <= $rtwwpge_star_html; $i++ )
				{
					$starrating->outertext .= $rtwwpge_starreview_html;
				}
				for( $i = 1; $i <= 5-$rtwwpge_star_html; $i++ )
				{
					$starrating->outertext .= '<span class="elementor-star-empty" style="color: #fdcc0d; font-size: 25px;">☆</span>';
				}
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_starreview_html = '';
            foreach($rtwwpge_dom_obj->find('.star-rating strong') as $strnull)
			{
				$strnull->innertext ='';
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*Add class in li of product-list-widget*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_myprd_html = '';
            foreach($rtwwpge_dom_obj->find('.product_list_widget li') as $dv)
			{
				$rtwwpge_myprd_html =$dv->innertext;
				$dv->outertext ='<li class="elementor-prd">'.$rtwwpge_myprd_html.'</li>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Working for product_list_widget image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_myprdimg_html = '';
            foreach($rtwwpge_dom_obj->find('.product_list_widget img') as $dvimg)
			{
				$rtwwpge_myprdimg_html =$dvimg->addClass('elementor-prd-img');
				$dvimg->outertext =$rtwwpge_myprdimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Working fop gallery image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_egal_html = '';
			foreach($rtwwpge_dom_obj->find('.elementor-gallery__container .e-gallery-image') as $eval)
			{
				$rtwwpge_egal_html =$eval->getAttribute('data-thumbnail');
				$eval->outertext .='<div class="rtwwpge-imggal">
								   	  <img src='.$rtwwpge_egal_html.'>
								   </div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Working for review star*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_srate_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-star-full') as $ssr)
			{
				$rtwwpge_srate_html =$ssr->innertext;
				$ssr->outertext ='<span class="elementor-star-full" style="color: #fdcc0d; font-size: 25px;">★</span>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_sratenull_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-star-empty') as $ssrnull)
			{
				$rtwwpge_sratenull_html =$ssrnull->innertext;
				$ssrnull->outertext ='<span class="elementor-star-empty" style="color: #fdcc0d; font-size:25px;">☆</span>';
			}
			
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_startitle_html = '';
			foreach($rtwwpge_dom_obj->find('.elementor-star-rating .elementor-screen-only') as $starnullval)
			{
				$starnullval->innertext ='';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*Working for cart element of wordpress widget*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwpgaeb_cartitem_html = '';
            foreach($rtwwpge_dom_obj->find('.widget_shopping_cart .widget_shopping_cart_content') as $cartval)
			{
				$rtwpgaeb_cartitem_html ='<div class="elementor-menu-cart__subtotal">
				                            <strong>Subtotal:</strong>
											<span class="woocommerce-Price-amount amount">
												<span class="woocommerce-Price-currencySymbol">£</span>
												'.$stotal.'.00.'.'
											</span>
										  </div>
										  <div class="elementor-menu-cart__footer-buttons">
										  		<div style="margin-bottom: 10px;padding: 5px;background-color: #818a91;margin-left: 5px;margin-right: 5px;">
													<a href="'.$urlcart.'" class="elementor-buttonn elementor-button--view-cart elementor-size-md" download>
													    <span class="elementor-button-text">View cart</span>
													</a>
												</div>
												<div style="margin-bottom:10px;padding: 5px;background-color: #818a91;margin-left: 5px;margin-right: 5px;">
													<a href="'.$checkout_url.'" class="elementor-buttonn elementor-button--checkout elementor-size-md">
													   <span class="elementor-button-text">Checkout</span>
													</a>
												</div>
										  </div>';
										 
				$cartval->innertext = $rtw_menucarthtml.$rtwpgaeb_cartitem_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*Put the content in div of swiper-slide-bg*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remslide_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-slides .swiper-slide .swiper-slide-bg') as $innhtml)
			{
			    $innhtml->outertext ='';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_slidee_html = '';
            foreach($rtwwpge_dom_obj->find('.swiper-slide-contents') as $innerrhtml)
			{
				$rtwwpge_slidee_html =$innerrhtml->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_slide_html = '';
            foreach($rtwwpge_dom_obj->find('.swiper-slide-inner') as $innerhtml)
			{
				$rtwwpge_slide_html ='<div class="swiper-slide-bg">
									    <div class="swiper-slide-inner">'.$innerhtml->innertext.'</div>
									  </div>';
				$innerhtml->outertext =$rtwwpge_slide_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Add class in elementor-grid-item*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_grid_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-grid .elementor-grid-item') as $dvimg)
			{
				$rtwwpge_grid_html =$dvimg->addClass('elementor_griditem');
				$dvimg->outertext =$rtwwpge_grid_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Working for countdown*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_time_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-countdown-wrapper') as $timeval)
			{
				$rtwwpge_time_html =$timeval->getAttribute('data-date');
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_evertime_html = 0;
            foreach($rtwwpge_dom_obj->find('.elementor-countdown-wrapper') as $evertimeval)
			{
				$rtwwpge_evertime_html =$evertimeval->getAttribute('data-evergreen-interval');
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			if($rtwwpge_time_html)
			{
				$rtwwpge_duedate =date("Y-m-d h:i:s",$rtwwpge_time_html);
				$rtwwpge_date1 = new DateTime("now");
				$rtwwpge_date2 = new DateTime($rtwwpge_duedate);
				$rtwwpge_df = $rtwwpge_date1->diff($rtwwpge_date2);

				if( isset($rtwwpge_df) && is_object($rtwwpge_df) && !empty($rtwwpge_df) )
				{	
					$days = $rtwwpge_df->days;
					$hours = $rtwwpge_df->h;
					$minutes = $rtwwpge_df->i;
					$seconds = $rtwwpge_df->s;
				}
		    }
			else
			{
				$rtwwpge_current = strtotime(date('Y-m-d h:i:s', current_time('timestamp')));
				$rtwwpge_current = $rtwwpge_current + $rtwwpge_evertime_html;
				$rtwwpge_date = date('Y-m-d h:i:s',$rtwwpge_current);
				$rtwwpge_date1 = new DateTime("now");
				$rtwwpge_date2 = new DateTime($rtwwpge_date);
				$rtwwpge_df = $rtwwpge_date1->diff($rtwwpge_date2);

				if( isset($rtwwpge_df) && is_object($rtwwpge_df) && !empty($rtwwpge_df) )
				{	
				$days = $rtwwpge_df->days;
				$hours = $rtwwpge_df->h;
				$minutes = $rtwwpge_df->i;
				$seconds = $rtwwpge_df->s;
				}
		    }

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_countday_html .='<div class="elementor-countdown-digits elementor-countdown-days">'.$days.'</div>
									    <span class="elementor-countdown-label">Days</span>';

			foreach($rtwwpge_dom_obj->find('.elementor-countdown-wrapper div[1]') as $countval)
			{
				$countval->innertext =$rtwwpge_countday_html;
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_counthr_html .='<div class="elementor-countdown-digits elementor-countdown-days">'.$hours.'</div>
									 <span class="elementor-countdown-label">Hours</span>';
									 
            foreach($rtwwpge_dom_obj->find('.elementor-countdown-wrapper div[2]') as $counhrval)
			{
				$counhrval->innertext =$rtwwpge_counthr_html;
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_countmin_html .='<div class="elementor-countdown-digits elementor-countdown-days">'.$minutes.'</div>
									   <span class="elementor-countdown-label">Minutes</span>';

			foreach($rtwwpge_dom_obj->find('.elementor-countdown-wrapper div[3]') as $counminval)
			{
				$counminval->innertext =$rtwwpge_countmin_html;
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_countsec_html .= '<div class="elementor-countdown-digits elementor-countdown-days">'.$seconds.'</div>
									    <span class="elementor-countdown-label">Seconds</span>';

			foreach($rtwwpge_dom_obj->find('.elementor-countdown-wrapper div[4]') as $counsecval)
			{
				$counsecval->innertext =$rtwwpge_countsec_html;
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*image-box-wrapper figure change in div*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_figure_html = '';

			foreach($rtwwpge_dom_obj->find('.elementor-image-box-wrapper figure') as $figval)
			{
				$rtwwpge_figure_html =$figval->innertext;
				$figval->outertext ='<div class="elementor-image-box-image">'.$rtwwpge_figure_html.'</div>';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			foreach($rtwwpge_dom_obj->find('.elementor-image-box-image img') as $wdht)
			{
				$wdht->width=170;
				$wdht->height=170;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*facebook social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_socialicon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-facebook i') as $sicon)
			{
				$rtwwpge_socialicon_html =$sicon->innertext;
				$rtwwpge_socialicon_html ='';
				$sicon->outertext =$rtwwpge_socialicon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*facebook social icon image*/
            $rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_fbicon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-facebook') as $ficon)
			{
				$rtwwpge_fbicon_html =$ficon->innertext;
				$rtwwpge_fbicon_html .='<img src="'.RTWWPGE_URL.'public/images/Facebook.png" style="width: 35px; height: 35px; margin-top: 10px;">';
				$ficon->outertext =$rtwwpge_fbicon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*twitter social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_socialtwticon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-twitter i') as $ttwicon)
			{
				$rtwwpge_socialtwticon_html =$ttwicon->innertext;
				$rtwwpge_socialtwticon_html ='';
				$ttwicon->outertext =$rtwwpge_socialtwticon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*twitter social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_twitricon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-twitter') as $twtticon)
			{
				$rtwwpge_twitricon_html =$twtticon->innertext;
				$rtwwpge_twitricon_html .='<img src="'.RTWWPGE_URL.'public/images/twitter.png" style="width: 35px; height: 35px;margin-top: 10px;">';
				$twtticon->outertext =$rtwwpge_twitricon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*github social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_youicon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-youtube i') as $ytbicon)
			{
				$rtwwpge_youicon_html =$ytbicon->innertext;
				$rtwwpge_youicon_html ='';
				$ytbicon->outertext =$rtwwpge_youicon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*youtube social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_ytbbicon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-youtube') as $twtticon)
			{
				$rtwwpge_ytbbicon_html =$twtticon->innertext;
				$rtwwpge_ytbbicon_html .='<img src="'.RTWWPGE_URL.'public/images/youtube.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $twtticon->outertext =$rtwwpge_ytbbicon_html;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*github social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_github_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-github i') as $gticon)
			{
				$rtwwpge_github_html =$gticon->innertext;
				$rtwwpge_github_html ='';
				$gticon->outertext =$rtwwpge_github_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*github social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_gthb_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-github') as $gthubicon)
			{
				$rtwwpge_gthb_html =$gthubicon->innertext;
				$rtwwpge_gthb_html .='<img src="'.RTWWPGE_URL.'public/images/github.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $gthubicon->outertext =$rtwwpge_gthb_html;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*wordpress social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_wordpress_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-wordpress i') as $wpicon)
			{
				$rtwwpge_wordpress_html =$wpicon->innertext;
				$rtwwpge_wordpress_html ='';
				$wpicon->outertext =$rtwwpge_wordpress_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*wordpress social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_wp_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-wordpress') as $wordpicon)
			{
				$rtwwpge_wp_html =$wordpicon->innertext;
				$rtwwpge_wp_html .='<img src="'.RTWWPGE_URL.'public/images/wordpress.jpg" style="width: 35px; height: 35px;margin-top: 10px;">';
                $wordpicon->outertext =$rtwwpge_wp_html;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*apple social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_apple_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-apple i') as $apicon)
			{
				$rtwwpge_apple_html =$apicon->innertext;
				$rtwwpge_apple_html ='';
				$apicon->outertext =$rtwwpge_apple_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*apple social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_app_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-apple') as $applicon)
			{
				$rtwwpge_app_html =$applicon->innertext;
				$rtwwpge_app_html .='<img src="'.RTWWPGE_URL.'public/images/apple.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $applicon->outertext =$rtwwpge_app_html;
			}
            $rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*android social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_android_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-android i') as $adicon)
			{
				$rtwwpge_android_html =$adicon->innertext;
				$rtwwpge_android_html ='';
				$adicon->outertext =$rtwwpge_android_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*android social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_andr_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-android') as $andricon)
			{
				$rtwwpge_andr_html =$andricon->innertext;
				$rtwwpge_andr_html .='<img src="'.RTWWPGE_URL.'public/images/android.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $andricon->outertext =$rtwwpge_andr_html;
					
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*instagram social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_instaa_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-instagram i') as $innss)
			{
				$rtwwpge_instaa_html =$innss->innertext;
				$rtwwpge_instaa_html ='';
				$innss->outertext =$rtwwpge_instaa_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*instagram social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_instaagrm_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-instagram') as $insstt)
			{
				$rtwwpge_instaagrm_html =$insstt->innertext;
				$rtwwpge_instaagrm_html .='<img src="'.RTWWPGE_URL.'public/images/insta.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $insstt->outertext =$rtwwpge_instaagrm_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*linkedin social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_lkdin_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-linkedin i') as $likdn)
			{
				$rtwwpge_lkdin_html =$likdn->innertext;
				$rtwwpge_lkdin_html ='';
				$likdn->outertext =$rtwwpge_lkdin_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*linkedin social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_linkkkdd_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-linkedin') as $lnddkin)
			{
				$rtwwpge_linkkkdd_html =$lnddkin->innertext;
				$rtwwpge_linkkkdd_html .='<img src="'.RTWWPGE_URL.'public/images/Linkedin.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $lnddkin->outertext =$rtwwpge_linkkkdd_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*medium social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_medium_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-medium i') as $micon)
			{
				$rtwwpge_medium_html =$micon->innertext;
				$rtwwpge_medium_html ='';
				$micon->outertext =$rtwwpge_medium_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*medium social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_mdm_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-medium') as $mmicon)
			{
				$rtwwpge_mdm_html =$mmicon->innertext;
				$rtwwpge_mdm_html .='<img src="'.RTWWPGE_URL.'public/images/medium.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $mmicon->outertext =$rtwwpge_mdm_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*odnoklassniki social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_odnoklassniki_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-odnoklassniki i') as $odnok)
			{
				$rtwwpge_odnoklassniki_html =$odnok->innertext;
				$rtwwpge_odnoklassniki_html ='';
				$odnok->outertext =$rtwwpge_odnoklassniki_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*odnoklassniki social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_odnoklassni_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-odnoklassniki') as $odnoklass)
			{
				$rtwwpge_odnoklassni_html =$odnoklass->innertext;
				$rtwwpge_odnoklassni_html .='<img src="'.RTWWPGE_URL.'public/images/ok.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $odnoklass->outertext =$rtwwpge_odnoklassni_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*pinterest social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pinterestt_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-pinterest i') as $pnt)
			{
				$rtwwpge_pinterestt_html =$pnt->innertext;
				$rtwwpge_pinterestt_html ='';
				$pnt->outertext =$rtwwpge_pinterestt_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*pinterest social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pntrst_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-pinterest') as $prst)
			{
				$rtwwpge_pntrst_html =$prst->innertext;
				$rtwwpge_pntrst_html .='<img src="'.RTWWPGE_URL.'public/images/Pinterest.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $prst->outertext =$rtwwpge_pntrst_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*reddit social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_redditt_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-reddit i') as $rdt)
			{
				$rtwwpge_redditt_html =$rdt->innertext;
				$rtwwpge_redditt_html ='';
				$rdt->outertext =$rtwwpge_redditt_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*reddit social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_redet_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-reddit') as $rdttt)
			{
				$rtwwpge_redet_html =$rdttt->innertext;
				$rtwwpge_redet_html .='<img src="'.RTWWPGE_URL.'public/images/reddit.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $rdttt->outertext =$rtwwpge_redet_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*skype social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_skypee_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-skype i') as $syp)
			{
				$rtwwpge_skypee_html =$syp->innertext;
				$rtwwpge_skypee_html ='';
				$syp->outertext =$rtwwpge_skypee_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*skype social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_skypy_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-skype') as $sypp)
			{
				$rtwwpge_skypy_html =$sypp->innertext;
				$rtwwpge_skypy_html .='<img src="'.RTWWPGE_URL.'public/images/skype.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $sypp->outertext =$rtwwpge_skypy_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*telegram social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_teligram_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-telegram i') as $tlg)
			{
				$rtwwpge_teligram_html =$tlg->innertext;
				$rtwwpge_teligram_html ='';
				$tlg->outertext =$rtwwpge_teligram_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*telegram social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_teligg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-telegram') as $tlig)
			{
				$rtwwpge_teligg_html =$tlig->innertext;
				$rtwwpge_teligg_html .='<img src="'.RTWWPGE_URL.'public/images/telegram.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $tlig->outertext =$rtwwpge_teligg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*vibe social icon i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_viber_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-viber i') as $vbb)
			{
				$rtwwpge_viber_html =$vbb->innertext;
				$rtwwpge_viber_html ='';
				$vbb->outertext =$rtwwpge_viber_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*vibe social icon image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_viberr_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-social-icon-viber') as $vbr)
			{
				$rtwwpge_viberr_html =$vbr->innertext;
				$rtwwpge_viberr_html .='<img src="'.RTWWPGE_URL.'public/images/viber.png" style="width: 35px; height: 35px;margin-top: 10px;">';
                $vbr->outertext =$rtwwpge_viberr_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*Add class in element-button-content-wrapper*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_elebtn_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-widget-wc-add-to-cart .elementor-button-content-wrapper') as $elbtn)
			{
				$rtwwpge_elebtn_html =$elbtn->addClass('rtwwpge_elementor_button');
				$elbtn->outertext =$rtwwpge_elebtn_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*facebook share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_fcbtimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_facebook .elementor-share-btn__icon') as $fabimg)
			{
				$rtwwpge_fcbtimg_html =$fabimg->innertext;
				$rtwwpge_fcbtimg_html ='';
				$fabimg->innertext =$rtwwpge_fcbtimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*facebook share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_fbimgadd_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_facebook .elementor-share-btn__icon') as $fcaaimg)
			{
				$rtwwpge_fbimgadd_html ='<img src="'.RTWWPGE_URL.'public/images/Facebook.png" style="width: 25px;margin-top: 5px;">
				                          <span class="elementor-screen-only">Share on facebook</span>';
				$fcaaimg->innertext =$rtwwpge_fbimgadd_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*facebook share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remfbimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_facebook .elementor-share-btn__icon .elementor-screen-only') as $rmimg)
			{
				$rtwwpge_remfbimg_html =$rmimg->innertext;
				$rtwwpge_remfbimg_html ='';
				$rmimg->innertext =$rtwwpge_remfbimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*twitter share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_twtimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_twitter .elementor-share-btn__icon') as $twtimg)
			{
				$rtwwpge_twtimg_html =$twtimg->innertext;
				$rtwwpge_twtimg_html ='';
				$insimg->innertext =$rtwwpge_twtimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*twitter share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_twtrimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_twitter .elementor-share-btn__icon') as $twterimg)
			{
				$rtwwpge_twtrimg_html ='<img src="'.RTWWPGE_URL.'public/images/twitter.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                         <span class="elementor-screen-only">Share on twitter</span>';
				$twterimg->innertext =$rtwwpge_twtrimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*twitter share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remtwtimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_twitter .elementor-share-btn__icon .elementor-screen-only') as $twttimg)
			{
				$rtwwpge_remtwtimg_html =$twttimg->innertext;
				$rtwwpge_remtwtimg_html ='';
				$twttimg->innertext =$rtwwpge_remtwtimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*linkedin share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_lkdimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_linkedin .elementor-share-btn__icon') as $ldimg)
			{
				$rtwwpge_lkdimg_html =$ldimg->innertext;
				$rtwwpge_lkdimg_html ='';
				$ldimg->innertext =$rtwwpge_lkdimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*linkedin share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_linkimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_linkedin .elementor-share-btn__icon') as $linkedimg)
			{
				$rtwwpge_linkimg_html ='<img src="'.RTWWPGE_URL.'public/images/Linkedin.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                         <span class="elementor-screen-only">Share on linkedin</span>';
				$linkedimg->innertext =$rtwwpge_linkimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*linkedin share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remldimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_linkedin .elementor-share-btn__icon .elementor-screen-only') as $lddimg)
			{
				$rtwwpge_remldimg_html =$lddimg->innertext;
				$rtwwpge_remldimg_html ='';
				$lddimg->innertext =$rtwwpge_remldimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*google+ share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_google_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_google .elementor-share-btn__icon') as $ggl)
			{
				$rtwwpge_google_html =$ggl->innertext;
				$rtwwpge_google_html ='';
				$ggl->innertext =$rtwwpge_google_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*google+ share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_gglim_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_google .elementor-share-btn__icon') as $googleimg)
			{
				$rtwwpge_gglim_html ='<img src="'.RTWWPGE_URL.'public/images/googleplus.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                        <span class="elementor-screen-only">Share on google+</span>';
				$googleimg->innertext =$rtwwpge_gglim_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*google+ share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remggl_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_google .elementor-share-btn__icon .elementor-screen-only') as $rggl)
			{
				$rtwwpge_remggl_html =$rggl->innertext;
				$rtwwpge_remggl_html ='';
				$rggl->innertext =$rtwwpge_remggl_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*pinterest share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pinterest_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_pinterest .elementor-share-btn__icon') as $pin)
			{
				$rtwwpge_pinterest_html =$pin->innertext;
				$rtwwpge_pinterest_html ='';
				$pin->innertext =$rtwwpge_pinterest_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*pinterest share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pint_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_pinterest .elementor-share-btn__icon') as $pintt)
			{
				$rtwwpge_pint_html ='<img src="'.RTWWPGE_URL.'public/images/Pinterest.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                      <span class="elementor-screen-only">Share on pinterest</span>';
				$pintt->innertext =$rtwwpge_pint_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*pinterest share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_rempin_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_pinterest .elementor-share-btn__icon .elementor-screen-only') as $rpin)
			{
				$rtwwpge_rempin_html =$rpin->innertext;
				$rtwwpge_rempin_html ='';
				$rpin->innertext =$rtwwpge_rempin_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*reddit share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_reddit_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_reddit .elementor-share-btn__icon') as $redd)
			{
				$rtwwpge_reddit_html =$redd->innertext;
				$rtwwpge_reddit_html ='';
				$redd->innertext =$rtwwpge_reddit_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*reddit share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_reddd_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_reddit .elementor-share-btn__icon') as $reddit)
			{
				$rtwwpge_reddd_html ='<img src="'.RTWWPGE_URL.'public/images/reddit.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                        <span class="elementor-screen-only">Share on reddit</span>';
				$reddit->innertext =$rtwwpge_reddd_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*reddit share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remred_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_reddit .elementor-share-btn__icon .elementor-screen-only') as $rred)
			{
				$rtwwpge_remred_html =$rred->innertext;
				$rtwwpge_remred_html ='';
				$rred->innertext =$rtwwpge_remred_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*vk share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_vk_html = '';
           foreach($rtwwpge_dom_obj->find('.elementor-share-btn_vk .elementor-share-btn__icon') as $vkkk)
			{
				$rtwwpge_vk_html =$vkkk->innertext;
				$rtwwpge_vk_html ='';
				$vkkk->innertext =$rtwwpge_vk_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*vk share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_vkk_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_vk .elementor-share-btn__icon') as $vvk)
			{
				$rtwwpge_vkk_html ='<img src="'.RTWWPGE_URL.'public/images/vk.png" style="width: 25px; height: 25px; margin-top: 5px;"><span class="elementor-screen-only">Share on vk</span>';
				$vvk->innertext =$rtwwpge_vkk_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*vk share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remvk_html = '';
           foreach($rtwwpge_dom_obj->find('.elementor-share-btn_vk .elementor-share-btn__icon .elementor-screen-only') as $rvk)
			{
				$rtwwpge_remvk_html =$rvk->innertext;
				$rtwwpge_remvk_html ='';
				$rvk->innertext =$rtwwpge_remvk_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*odnoklassniki share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_ok_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_odnoklassniki .elementor-share-btn__icon') as $okkk)
			{
				$rtwwpge_ok_html =$okkk->innertext;
				$rtwwpge_ok_html ='';
				$okkk->innertext =$rtwwpge_ok_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*odnoklassniki share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_okk_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_odnoklassniki .elementor-share-btn__icon') as $ook)
			{
				$rtwwpge_okk_html ='<img src="'.RTWWPGE_URL.'public/images/ok.png" style="width: 25px; height: 25px; margin-top: 5px;"><span class="elementor-screen-only">Share on ok</span>';
				$ook->innertext =$rtwwpge_okk_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*odnoklassniki share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remok_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_odnoklassniki .elementor-share-btn__icon .elementor-screen-only') as $rok)
			{
				$rtwwpge_remok_html =$rok->innertext;
				$rtwwpge_remok_html ='';
				$rok->innertext =$rtwwpge_remok_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*delicious share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_delicious_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_delicious .elementor-share-btn__icon') as $deli)
			{
				$rtwwpge_delicious_html =$deli->innertext;
				$rtwwpge_delicious_html ='';
				$deli->innertext =$rtwwpge_delicious_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*delicious share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_deli_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_delicious .elementor-share-btn__icon') as $delli)
			{
				$rtwwpge_deli_html ='<img src="'.RTWWPGE_URL.'public/images/delicious.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                      <span class="elementor-screen-only">Share on delicious</span>';
				$delli->innertext =$rtwwpge_deli_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			
			/*delicious share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remdeli_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_delicious .elementor-share-btn__icon .elementor-screen-only') as $rdel)
			{
				$rtwwpge_remdeli_html =$rdel->innertext;
				$rtwwpge_remdeli_html ='';
				$rdel->innertext =$rtwwpge_remdeli_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			
			/*skype share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_skype_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_skype .elementor-share-btn__icon') as $sky)
			{
				$rtwwpge_skype_html =$sky->innertext;
				$rtwwpge_skype_html ='';
				$sky->innertext =$rtwwpge_skype_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			
			/*skype share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_skyy_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_skype .elementor-share-btn__icon') as $skyp)
			{
				$rtwwpge_skyy_html ='<img src="'.RTWWPGE_URL.'public/images/skype.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                      <span class="elementor-screen-only">Share on skype</span>';
				$skyp->innertext =$rtwwpge_skyy_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*skype share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remskype_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_skype .elementor-share-btn__icon .elementor-screen-only') as $rsky)
			{
				$rtwwpge_remskype_html =$rsky->innertext;
				$rtwwpge_remskype_html ='';
				$rsky->innertext =$rtwwpge_remskype_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*stumbleupon share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_stumbleupon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_stumbleupon .elementor-share-btn__icon') as $stm)
			{
				$rtwwpge_stumbleupon_html =$stm->innertext;
				$rtwwpge_stumbleupon_html ='';
				$stm->innertext =$rtwwpge_stumbleupon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*stumbleupon share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_stumbleup_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_stumbleupon .elementor-share-btn__icon') as $stmbl)
			{
				$rtwwpge_stumbleup_html ='<img src="'.RTWWPGE_URL.'public/images/stumbleupon.png" style="width: 25px; height: 25px; margin-top: 5px;"><span class="elementor-screen-only">Share on stumbleupon</span>';
				$stmbl->innertext =$rtwwpge_stumbleup_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*stumbleupon share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remstml_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_stumbleupon .elementor-share-btn__icon .elementor-screen-only') as $rstmbl)
			{
				$rtwwpge_remstml_html =$rstmbl->innertext;
				$rtwwpge_remstml_html ='';
				$rstmbl->innertext =$rtwwpge_remstml_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*telegram share-btn i null*/
            $rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_telegram_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_telegram .elementor-share-btn__icon') as $tele)
			{
				$rtwwpge_telegram_html =$tele->innertext;
				$rtwwpge_telegram_html ='';
				$tele->innertext =$rtwwpge_telegram_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*telegram share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_tele_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_telegram .elementor-share-btn__icon') as $teleg)
			{
				$rtwwpge_tele_html ='<img src="'.RTWWPGE_URL.'public/images/telegram.png" style="width: 25px; height: 25px; margin-top: 5px;">
				                      <span class="elementor-screen-only">Share on telegram</span>';
				$teleg->innertext =$rtwwpge_tele_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*telegram share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remtele_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_telegram .elementor-share-btn__icon .elementor-screen-only') as $rtele)
			{
				$rtwwpge_remtele_html =$rtele->innertext;
				$rtwwpge_remtele_html ='';
				$rtele->innertext =$rtwwpge_remtele_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*pocket share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pocket_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_pocket .elementor-share-btn__icon') as $poct)
			{
				$rtwwpge_pocket_html =$poct->innertext;
				$rtwwpge_pocket_html ='';
				$poct->innertext =$rtwwpge_pocket_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*pocket share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_poctt_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_pocket .elementor-share-btn__icon') as $pocc)
			{
				$rtwwpge_poctt_html ='<img src="'.RTWWPGE_URL.'public/images/pocket.jpeg" style="width: 25px; height: 25px; margin-top: 5px;">
				                       <span class="elementor-screen-only">Share on pocket</span>';
				$pocc->innertext =$rtwwpge_poctt_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*pocket share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_rempoc_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_pocket .elementor-share-btn__icon .elementor-screen-only') as $rpoc)
			{
				$rtwwpge_rempoc_html =$rpoc->innertext;
				$rtwwpge_rempoc_html ='';
				$rpoc->innertext =$rtwwpge_rempoc_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*xing share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_xing_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_xing .elementor-share-btn__icon') as $xingg)
			{
				$rtwwpge_xing_html =$xingg->innertext;
				$rtwwpge_xing_html ='';
				$xingg->innertext =$rtwwpge_xing_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*xing share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_xingg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_xing .elementor-share-btn__icon') as $xingk)
			{
				$rtwwpge_xingg_html ='<img src="'.RTWWPGE_URL.'public/images/xing.png" style="width: 25px; height: 25px; margin-top: 5px;"><span class="elementor-screen-only">Share on xing</span>';
				$xingk->innertext =$rtwwpge_xingg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*xing share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remxing_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_xing .elementor-share-btn__icon .elementor-screen-only') as $rxing)
			{
				$rtwwpge_remxing_html =$rxing->innertext;
				$rtwwpge_remxing_html ='';
				$rxing->innertext =$rtwwpge_remxing_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*whatsappp share-btn i null*/
            $rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_whatsapp_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_whatsapp .elementor-share-btn__icon') as $wasp)
			{
				$rtwwpge_whatsapp_html =$wasp->innertext;
				$rtwwpge_whatsapp_html ='';
				$wasp->innertext =$rtwwpge_whatsapp_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*whatsappp share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_wasup_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_whatsapp .elementor-share-btn__icon') as $waspp)
			{
				$rtwwpge_wasup_html ='<img src="'.RTWWPGE_URL.'public/images/whatsapp.jpeg" style="width: 25px; height: 25px;margin-top: 5px;"><span class="elementor-screen-only">Share on whatsapp</span>';
				$waspp->innertext =$rtwwpge_wasup_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*whatsappp share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remwasp_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_whatsapp .elementor-share-btn__icon .elementor-screen-only') as $rwasp)
			{
				$rtwwpge_remwasp_html =$rwasp->innertext;
				$rtwwpge_remwasp_html ='';
				$rwasp->innertext =$rtwwpge_remwasp_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*email share-btn i null*/
            $rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_email_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_email .elementor-share-btn__icon') as $eml)
			{
				$rtwwpge_email_html =$eml->innertext;
				$rtwwpge_email_html ='';
				$eml->innertext =$rtwwpge_email_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*email share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_eml_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_email .elementor-share-btn__icon') as $emll)
			{
				$rtwwpge_eml_html ='<img src="'.RTWWPGE_URL.'public/images/email.png" style="width: 25px; height: 25px;margin-top: 5px;"><span class="elementor-screen-only">Share on email</span>';
				$emll->innertext =$rtwwpge_eml_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*email share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_rememl_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_email .elementor-share-btn__icon .elementor-screen-only') as $rmll)
			{
				$rtwwpge_rememl_html =$rmll->innertext;
				$rtwwpge_rememl_html ='';
				$rmll->innertext =$rtwwpge_rememl_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*digg share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_print_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_print .elementor-share-btn__icon') as $prnt)
			{
				$rtwwpge_print_html =$prnt->innertext;
				$rtwwpge_print_html ='';
				$prnt->innertext =$rtwwpge_print_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*print share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_prn_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_print .elementor-share-btn__icon') as $prrn)
			{
				$rtwwpge_prn_html ='<img src="'.RTWWPGE_URL.'public/images/print.png" style="width: 25px; height: 25px; margin-top: 5px;"><span class="elementor-screen-only">Share on print</span>';
				$prrn->innertext =$rtwwpge_prn_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*print share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remprint_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_print .elementor-share-btn__icon .elementor-screen-only') as $rprint)
			{
				$rtwwpge_remprint_html =$rprint->innertext;
				$rtwwpge_remprint_html ='';
				$rprint->innertext =$rtwwpge_remprint_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*digg share-btn i null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_digg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_digg .elementor-share-btn__icon') as $digg)
			{
				$rtwwpge_digg_html =$digg->innertext;
				$rtwwpge_digg_html ='';
				$digg->innertext =$rtwwpge_digg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*digg share-btn image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_dgg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_digg .elementor-share-btn__icon') as $dgy)
			{
				$rtwwpge_dgg_html ='<img src="'.RTWWPGE_URL.'public/images/digg.png" style="width: 25px; height: 25px; margin-top: 5px;"><span class="elementor-screen-only">Share on print</span>';
				$dgy->innertext =$rtwwpge_dgg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*digg share-btn null screenonly*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_remdigg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-share-btn_digg .elementor-share-btn__icon .elementor-screen-only') as $rdigg)
			{
				$rtwwpge_remdigg_html =$rdigg->innertext;
				$rtwwpge_remdigg_html ='';
				$rdigg->innertext =$rtwwpge_remdigg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*blockquote tweet label*/
            $rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_blocktwtimgtext_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-blockquote__tweet-button .elementor-blockquote__tweet-label') as $btwttext)
			{
				$rtwwpge_blocktwtimgtext_html =$btwttext->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*blockquote footer cite html*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_bblocktwtimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-blockquote footer cite') as $bbtwtimg)
			{
				$rtwwpge_bblocktwtimg_html =$bbtwtimg->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*Remove blockquote footer twitter*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_blocktwtimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-blockquote footer') as $btwtimg)
			{
				$rtwwpge_blocktwtimg_html =$btwtimg->innertext;
				$rtwwpge_blocktwtimg_html ='';
				$btwtimg->innertext =$rtwwpge_blocktwtimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*blockquote twitter image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_addtwtimg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-blockquote footer') as $adtwtimg)
			{
				$rtwwpge_addtwtimg_html ='<cite class="elementor-blockquote__author">'.$rtwwpge_bblocktwtimg_html.'</cite>
				                           <div class="elementor-blockquote__tweet-button">
												<img src="'.RTWWPGE_URL.'public/images/twitter.png" style="width: 10px; height: 10px;">
												<span class="elementor-blockquote__tweet-label">'.$rtwwpge_blocktwtimgtext_html.'</span>
										   </div>';
				$adtwtimg->innertext =$rtwwpge_addtwtimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/* Remove testimonial twitter html*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_testtwticon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-testimonial__header .elementor-testimonial__icon') as $testic)
			{
				$rtwwpge_testtwticon_html =$testic->innertext;
				$rtwwpge_testtwticon_html ='';
				$testic->innertext =$rtwwpge_testtwticon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*testimonial twitter image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_testimonialicon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-testimonial__icon') as $testtwtimg)
			{
				$rtwwpge_testimonialicon_html ='<img src="'.RTWWPGE_URL.'public/images/twitterlogo.png" style="width: 15px; height: 15px;"><span class="elementor-screen-only">Read More</span>';
				$testtwtimg->innertext =$rtwwpge_testimonialicon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*cart html null*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_carticon_html = '';
            foreach($rtwwpge_dom_obj->find('.rtwwpge_elementor_button .elementor-button-icon') as $cart)
			{
				$rtwwpge_carticon_html =$cart->innertext;
				$rtwwpge_carticon_html ='';
				$cart->innertext =$rtwwpge_carticon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/* cart image*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_cartttimg_html = '';
            foreach($rtwwpge_dom_obj->find('.rtwwpge_elementor_button .elementor-button-icon') as $carrt)
			{
				$rtwwpge_cartttimg_html ='<img src="'.RTWWPGE_URL.'public/images/cart.png" style="width: 10px; height: 10px; color: white;">';
				$carrt->innertext =$rtwwpge_cartttimg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();
			
			/*Change anchor button in div */
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_anchordiv_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-widget-wc-add-to-cart .elementor-button-wrapper .elementor-button') as $adiv)
			{
				$rtwwpge_anchordiv_html ='<div class="elementor-button elementor-size-sm" role="button">'.$adiv->innertext.'</div>';
				$adiv->outertext =$rtwwpge_anchordiv_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*For Menucart button*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_menucarticon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-menu-cart__toggle .elementor-button .elementor-button-icon') as $mcart)
			{
				$rtwwpge_menucarticon_html =$mcart->innertext;
				$rtwwpge_menucarticon_html ='';
				$mcart->innertext =$rtwwpge_menucarticon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*For Basic Widget Button*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_widgetbtn_html = '';
			foreach($rtwwpge_dom_obj->find('.elementor-widget-button .elementor-button-wrapper') as $wbtn)
			{
				$rtwwpge_widgetbtn_html ='<div class="elementor-button" style="border: 1px solid;">'.$wbtn->innertext.'</div>';
				$wbtn->innertext = $rtwwpge_widgetbtn_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*Working For Flip Box Button */
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_fltitle_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-flip-box__back .elementor-flip-box__layer__title')as $ftitle)
			{
				$rtwwpge_fltitle_html =$ftitle->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_fldesc_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-flip-box__back .elementor-flip-box__layer__description')as $fdesc)
			{
				$rtwwpge_fldesc_html =$fdesc->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_flippbtnn_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-flip-box__button') as $fpbn)
			{
				$rtwwpge_flippbtnn_html =$fpbn->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_flippbtnnhref_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-flip-box__button') as $fpbnn)
			{
				$rtwwpge_flippbtnnhref_html =$fpbnn->getAttribute('href');
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            $rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_flipboxhtml_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-flip-box__back .elementor-flip-box__layer__inner') as $flhtml)
			{
				$rtwwpge_flipboxhtml_html ='<div class="elementor-flip-box__layer__inner">
				                              <h3 class="elementor-flip-box__layer__title">'.$rtwwpge_fltitle_html.'						
										      </h3>
										      <div class="elementor-flip-box__layer__description">'.$rtwwpge_fldesc_html.'</div>
											  <div class="elementor-flip-box__button elementor-button elementor-size-sm" style="border: 2px solid #fff;margin-left: auto; margin-right: auto;color: white;">
												<a class="elementor-flip-box__button elementor-button elementor-size-sm" style="color: white;" href='.$rtwwpge_flippbtnnhref_html.'>'.$rtwwpge_flippbtnn_html.'</a>
											  </div>
										   </div>';
				$flhtml->outertext =$rtwwpge_flipboxhtml_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/*add the div above anchor*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_callaction_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-cta__button-wrapper') as $callbtn)
			{
				$rtwwpge_callaction_html ='<div class="elementor-cta__button elementor-button elementor-size-sm" style="border: 2px solid;margin-left: auto; margin-right: auto;">'.$callbtn->innertext.'</div>';
				$callbtn->innertext =$rtwwpge_callaction_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*Working For Price Table Button */
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_prcbtnin_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__button') as $prcca)
			{
				$rtwwpge_prcbtnin_html =$prcca->innertext;
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_prctextt_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__additional_info') as $prctxt)
			{
				$rtwwpge_prctextt_html =$prctxt->innertext;
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_prcanchor_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__button') as $prctxt)
			{
				$rtwwpge_prcanchor_html =$prctxt->getAttribute('href');
            }
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_prchtml_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__footer') as $prhtml)
			{
				$rtwwpge_prchtml_html ='<div class="elementor-price-table__footer">
											<div class="elementor-price-table__button elementor-button" style="margin-left: auto; margin-right: auto;">
												<a class="elementor-price-table__button elementor-button elementor-size-md" href='.$rtwwpge_prcanchor_html.'>'.$rtwwpge_prcbtnin_html.'</a>
											</div>
										    <div class="elementor-price-table__additional_info">'.$rtwwpge_prctextt_html.'</div>
										</div>';
				$prhtml->outertext =$rtwwpge_prchtml_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_iconboximg_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-icon-box-icon') as $iconimgg)
			{
				$rtwwpge_iconboximg_html ='<div class="elementor-icon-box-icon"><span class="elementor-icon elementor-animation-"><img src="'.RTWWPGE_URL.'public/images/starimage.png" style="width: 70px; height: 70px;margin-top: -15px;"></span></div>';
				$iconimgg->outertext =$rtwwpge_iconboximg_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*Working For Price Table roibbon*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pricetableribbon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table__ribbon .elementor-price-table__ribbon-inner') as $ribbon)
			{
				$rtwwpge_pricetableribbon_html =$ribbon->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_removeribbon_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-widget-container .elementor-price-table__ribbon') as $rribbon)
			{
				$rtwwpge_removeribbon_html =$rribbon->innertext;
				$rtwwpge_removeribbon_html ='';
				$rribbon->outertext =$rtwwpge_removeribbon_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_pricetableribb_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-price-table .elementor-price-table__header') as $ribbn)
			{
				$rtwwpge_pricetableribb_html ='<div class="elementor-price-table__header">'.$ribbn->innertext.'
												 <div class="elementor-price-table__ribbon">
												    <div class="elementor-price-table__ribbon-inner">'.$rtwwpge_pricetableribbon_html.'</div>
												 </div>
												</div>';
				
				$ribbn->outertext =$rtwwpge_pricetableribb_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

            /*Working Of Cta Ribbon*/
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_ctaribbn_html = '';
			foreach($rtwwpge_dom_obj->find('.elementor-ribbon-inner') as $ctarbn)
			{
				$rtwwpge_ctaribbn_html =$ctarbn->innertext;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_removeribboncta_html = '';
            foreach($rtwwpge_dom_obj->find('.elementor-cta .elementor-ribbon') as $cribbon)
			{
				$rtwwpge_removeribboncta_html =$cribbon->innertext;
				$rtwwpge_removeribboncta_html ='';
				$cribbon->outertext =$rtwwpge_removeribboncta_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_ctaribbninn_html = '';
			foreach($rtwwpge_dom_obj->find('.elementor-cta__bg-wrapper') as $ctarbnin)
			{
				$rtwwpge_ctaribbninn_html =$ctarbnin->innertext.'<div class="elementor-ribbon">
				                              <div class="elementor-ribbon-inner">'.$rtwwpge_ctaribbn_html.'</div>
											</div>';
				$ctarbnin->outertext = $rtwwpge_ctaribbninn_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_previcon_html ='';
			foreach($rtwwpge_dom_obj->find('.post-navigation__arrow-wrapper.post-navigation__arrow-prev') as $prvimg)
			{
				$rtwwpge_previcon_html =$prvimg->innertext;
				$rtwwpge_previcon_html ='';
				$prvimg->innertext ='<img src="'.RTWWPGE_URL.'public/images/previous.png" style="width: 10px; height: 10px;">';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_nextimg_html ='';
			foreach($rtwwpge_dom_obj->find('.post-navigation__arrow-wrapper.post-navigation__arrow-next') as $next)
			{
				$rtwwpge_nextimg_html =$next->innertext;
				$rtwwpge_nextimg_html ='';
				$next->innertext ='<img src="'.RTWWPGE_URL.'public/images/next.png" style="width: 10px; height: 10px;margin-top: 5px;">';
				
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_wdimg_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-widget-wp-widget-media_image img') as $wdimgg)
			{
				$wdimgg->width=200;
				$wdimgg->height=200;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_amount_html ='';
			foreach($rtwwpge_dom_obj->find('.woocommerce-Price-currencySymbol') as $amt)
			{
				$rtwwpge_amount_html =$amt->innertext;
				$rtwwpge_amount_html ='';
				$amt->innertext ='$';
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_allspan_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-prd .product-title') as $spdv)
			{
				$rtwwpge_allspan_html ='<div class="product-title">'.$spdv->innertext.'</div>';
				$spdv->outertext =$rtwwpge_allspan_html;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			ob_get_clean();

			if (file_exists(WP_PLUGIN_DIR . '/gtranslate/url_addon/config.php' || WP_PLUGIN_DIR . '/gtranslate/url_addon/gtranslate-email.php'))
			{
				if (isset($_SERVER['HTTP_X_GT_LANG']) && !empty($_SERVER['HTTP_X_GT_LANG']))
				{
					$rtwwpge_pdf_html = $this->rtwwpge_gtranslate($rtwwpge_pdf_html);
				}
			}
			$rtwwpge_mpdf->autoScriptToLang = true;
			$rtwwpge_mpdf->autoLangToFont = true;

			/* elementor-counter */
			$rtwwpge_dom_obj->load($rtwwpge_pdf_html);
			$rtwwpge_counter_html ='';
			foreach($rtwwpge_dom_obj->find('.elementor-counter-number') as $element)
			{
				$cvalue = $element->getAttribute('data-to-value');
				$element->innertext = $cvalue;
			}
			$rtwwpge_pdf_html = $rtwwpge_dom_obj->save();

			/* ------- Premium Addon Table Start ------- */
			if( is_plugin_active('premium-addons-for-elementor/premium-addons-for-elementor.php') )
			{
				$rtwwpge_premium_addon_table = new simple_html_dom();
				$rtwwpge_premium_addon_table->load( $rtwwpge_pdf_html );
				foreach ($rtwwpge_premium_addon_table->find('.premium-table-search') as $element) 
				{
					$outer_element = $element->outertext;
					$string_element = html_entity_decode($outer_element);
					$csv_substring = strchr($string_element,"https");
					$csv_substring = explode(',', $csv_substring);
					$csv_url = str_replace('\/', '/', $csv_substring[0]);
					$csv_url = str_replace('"', '', $csv_url);

			        $csv = array();
					$lines = file($csv_url, FILE_IGNORE_NEW_LINES);

					foreach ($lines as $key => $value) {
					    $csv[$key] = str_getcsv($value,';');
					}

					$prem_tabel = '';
					foreach ($csv as $index_key => $index_value) {
						$prem_tabel .= '<tr>';
						foreach ($index_value as $key => $val) {
							if ($index_key == 0) {
								$prem_tabel .= '<th>'.$val.'</th>';
							}
							else {
								$prem_tabel .= '<td>'.$val.'</td>';
							}
						}
						$prem_tabel .= '</tr>';
					}
					$element->innertext = $prem_tabel;
				}
				$rtwwpge_pdf_html = $rtwwpge_premium_addon_table->save();

				$rtwwpge_premium_addon_table->load( $rtwwpge_pdf_html );
				foreach ($rtwwpge_premium_addon_table->find('.premium-table-search tr td img') as $element)
				{
					$outer_element = $element->outertext;
					$src_attr = $element->setAttribute('width','100px');
					$src_attr = $element->setAttribute('height','100px');
				}
				$rtwwpge_pdf_html = $rtwwpge_premium_addon_table->save();
			}
			/* ------- Premium Addon Table Ends ------- */

			/* WooCommerce Single Product Page Template */
			$rtwwpge_single_product_html = '';
			if ( isset($this->rtwwpge_stng['rtwwpge_enable_singleprdt']) && $this->rtwwpge_stng['rtwwpge_enable_singleprdt'] == 1 && is_plugin_active('woocommerce/woocommerce.php') && is_product() )
			{
				$rtwwpge_data = array();
				$rtwwpge_product_atchmnt_id = array();
				$rtwwpge_single_pdt_obj = wc_get_product($post->ID);
				$rtwwpge_product_image = wp_get_attachment_image_src( get_post_thumbnail_id( $rtwwpge_single_pdt_obj->get_id() ), 'single-post-thumbnail' );
				$rtwwpge_product_name = $rtwwpge_single_pdt_obj->get_name();
				$rtwwpge_product_regular_price = wc_price( $rtwwpge_single_pdt_obj->get_regular_price() );
				$rtwwpge_product_sale_price = wc_price( $rtwwpge_single_pdt_obj->get_sale_price() );
				$rtwwpge_product_short_desc = $rtwwpge_single_pdt_obj->get_short_description();
				$rtwwpge_product_desc = $rtwwpge_single_pdt_obj->get_description();
				$rtwwpge_product_desc = preg_replace('/\[[^\]]*\]/', '', $rtwwpge_product_desc);
				$rtwwpge_product_desc = preg_replace('/<\/?[^>]+>/', '', $rtwwpge_product_desc);
				$rtwwpge_product_add_to_cart = add_query_arg('add-to-cart', $rtwwpge_single_pdt_obj->get_id(), wc_get_cart_url());
				$rtwwpge_product_image = wp_get_attachment_image_src( get_post_thumbnail_id( $rtwwpge_single_pdt_obj->get_id() ), 'single-post-thumbnail' );
				$rtwwpge_product_singleimg = $rtwwpge_product_image[0];
				$rtwwpge_product_thumb_image[]  = isset($rtwwpge_product_image[0])?$rtwwpge_product_image[0]:'';
				$attchmnt_id = $rtwwpge_single_pdt_obj->get_gallery_image_ids();
				foreach ($attchmnt_id as $key => $value) {
					array_push($rtwwpge_product_thumb_image, wp_get_attachment_url( $value ));
				}

				$rtwwpge_related_pdt = wc_get_related_products( $rtwwpge_single_pdt_obj->get_id(), 4 );
				if (!empty($rtwwpge_related_pdt) && isset($rtwwpge_related_pdt))
				{
					$cnts = 1;
					foreach ($rtwwpge_related_pdt as $relate_key => $relate_val)
					{
						$rtwwpge_relate_img[(wc_get_product( $relate_val ))->get_name()] = wp_get_attachment_image_src( get_post_thumbnail_id( $relate_val ), 'single-post-thumbnail' );
						$rtwwpge_data['add_to_cart_'.$cnts] = add_query_arg('add-to-cart', $relate_val, wc_get_cart_url()) ;
						$rtwwpge_data['add_to_cart_'.$cnts] = ( isset($rtwwpge_data['add_to_cart_'.$cnts]) ) ? $rtwwpge_data['add_to_cart_'.$cnts] : '' ;
						$cnts++;
					}
					$count = 1;
					foreach ($rtwwpge_relate_img as $related_k => $relate_v)
					{
						$rtwwpge_data['relate_img_'.$count] = $relate_v[0];
						$rtwwpge_data['relate_prod_'.$count] = $related_k;
						$count++;
					}
				}

				$rtwwpge_product_vari_attr = $rtwwpge_single_pdt_obj->get_attributes();
				if (!empty($rtwwpge_product_vari_attr)) {
					// $rtwwpge_product_attribute_slugs = array_keys($rtwwpge_product_vari_attr);
					foreach ($rtwwpge_product_vari_attr as $key => $value) {
						if ( strpos($value->get_name(), 'pa_') !== false ) {
							$strng = str_replace('pa_', '', $value->get_name());
						}
						else{
							$strng = $value->get_name();
						}
						$rtwwpge_product_attr_data[$strng] = $value->get_options();
					}

					foreach ($rtwwpge_product_attr_data as $nkey => $nvalue) {
						foreach ($nvalue as $keys => $vals) {
							$rtwwpge_product_attr_taxonomy[$nkey][] = get_term($vals)->name;
						}
					}
				}

				/* Single Product Templates */
				if ( isset($this->rtwwpge_stng['rtwwpge_prdt_template']) && $this->rtwwpge_stng['rtwwpge_prdt_template'] == 3 )
				{
					include RTWWPGE_DIR.'/public/partials/template/rtwwpge_single_product_template3.php';
				}
				elseif ( isset($this->rtwwpge_stng['rtwwpge_prdt_template']) && $this->rtwwpge_stng['rtwwpge_prdt_template'] == 2 )
				{
					include RTWWPGE_DIR.'/public/partials/template/rtwwpge_single_product_template2.php';
				}
				else
				{
					include RTWWPGE_DIR.'/public/partials/template/rtwwpge_single_product_template1.php';
				}

				/* Hide Related Product Section */
				$rtwwpge_dom_object->load( $rtwwpge_single_product_html );
				if ( isset($this->rtwwpge_stng['rtwwpge_hide_rp_singleprdt']) && $this->rtwwpge_stng['rtwwpge_hide_rp_singleprdt'] == 1 )
				{
					foreach ($rtwwpge_dom_object->find('#rtwwpge_related_products_section') as $element) {
						$element->outertext = '';
					}
					$rtwwpge_single_product_html = $rtwwpge_dom_object->save();
				}

				/* Hide Add To Cart Button (red main button) */
				$rtwwpge_dom_object->load( $rtwwpge_single_product_html );
				if ( isset($this->rtwwpge_stng['rtwwpge_hide_atc_singleprdt']) && $this->rtwwpge_stng['rtwwpge_hide_atc_singleprdt'] == 1 )
				{
					foreach ($rtwwpge_dom_object->find('#rtwwpge_product_add_to_cart') as $element) {
						$element->outertext = '';
					}
					$rtwwpge_single_product_html = $rtwwpge_dom_object->save();
				}

				$rtwwpge_pdf_html = $rtwwpge_single_product_html;
			}
			else
			{
				/* concatinating html with css */
				$rtwwpge_pdf_html = $rtwwpge_postcss_content.$rtwwpge_pdf_html;

				$rtwwpge_dom_objt = new simple_html_dom();
				/* Excluding Classes from PDF */
				if ( isset($_POST['rtwwpge_pdf_class']) && !empty($_POST['rtwwpge_pdf_class']) )
				{
					$rtwwpge_pdf_class = explode( ",", $_POST['rtwwpge_pdf_class'] );

					$rtwwpge_dom_objt->load( $rtwwpge_pdf_html );
					foreach ($rtwwpge_pdf_class as $class_val)
					{
						foreach ($rtwwpge_dom_objt->find('.'.$class_val) as $element) 
						{
							$element->outertext = '';
						}
					}
					$rtwwpge_pdf_html = $rtwwpge_dom_objt->save();
				}

				/* Excluding ID's from PDF */
				if ( isset($_POST['rtwwpge_pdf_id']) && !empty($_POST['rtwwpge_pdf_id']) )
				{
					$rtwwpge_pdf_id = explode( ",", $_POST['rtwwpge_pdf_id'] );

					$rtwwpge_dom_objt->load( $rtwwpge_pdf_html );
					foreach ($rtwwpge_pdf_id as $id_value)
					{
						foreach ($rtwwpge_dom_objt->find('#'.$id_value) as $element) 
						{
							$element->outertext = '';
						}
					}
					$rtwwpge_pdf_html = $rtwwpge_dom_objt->save();
				}
			}

			$rtwwpge_mpdf->WriteHTML($rtwwpge_pdf_html);

			if ( !is_dir ( RTWWPGE_PDF_DIR ) ) 
			{
				mkdir ( RTWWPGE_PDF_DIR, 0755, true );
			}
			$rtwwpge_mpdf->Output($rtwwpge_file_path,'F');
		}
	
		$rtwwpge_permalink = add_query_arg ( array( 'rtwwpge_generate_pdf' => 'true', 'rtwwpge_pdf_file' => $rtwwpge_file_name ), get_permalink ( $post->ID ) );
		ob_get_clean();
		echo json_encode( array('status' => true, 'rtwwpge_pdf_url' => $rtwwpge_permalink) );
		die();
	}

	function rtwwpge_gtranslate($rtwwpge_pdf_html)
	{
		include WP_PLUGIN_DIR . '/gtranslate/url_addon/config.php';
        $server_id = intval(substr(md5(preg_replace('/^www\./', '', $_SERVER['HTTP_HOST'])), 0, 5), 16) % count($servers);
        $server = $servers[$server_id];
        $host = $_SERVER['HTTP_X_GT_LANG'] . '.' . preg_replace('/^www\./', '', $_SERVER['HTTP_HOST']);
        $protocol = ((isset($_SERVER['HTTPS']) and ($_SERVER['HTTPS'] == 'on' or $_SERVER['HTTPS'] == 1)) or (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) and  $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https')) ? 'https' : 'http';

        $headers = array();
        $headers[] = 'Host: ' . $host;
        // add real visitor IP header
        if(isset($_SERVER['HTTP_CLIENT_IP']) and !empty($_SERVER['HTTP_CLIENT_IP']))
            $viewer_ip_address = $_SERVER['HTTP_CLIENT_IP'];
        if(isset($_SERVER['HTTP_CF_CONNECTING_IP']) and !empty($_SERVER['HTTP_CF_CONNECTING_IP']))
            $viewer_ip_address = $_SERVER['HTTP_CF_CONNECTING_IP'];
        if(isset($_SERVER['HTTP_X_SUCURI_CLIENTIP']) and !empty($_SERVER['HTTP_X_SUCURI_CLIENTIP']))
            $viewer_ip_address = $_SERVER['HTTP_X_SUCURI_CLIENTIP'];
        if(!isset($viewer_ip_address))
            $viewer_ip_address = $_SERVER['REMOTE_ADDR'];

        $headers[] = 'X-GT-Viewer-IP: ' . $viewer_ip_address;
        $headers[] = 'User-Agent: GTranslate-Email-Translate';

        // add X-Forwarded-For
        if(isset($_SERVER['HTTP_X_FORWARDED_FOR']) and !empty($_SERVER['HTTP_X_FORWARDED_FOR']))
            $headers[] = 'X-GT-Forwarded-For: ' . $_SERVER['HTTP_X_FORWARDED_FOR'];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $protocol.'://'.$server.'.tdn.gtranslate.net'.wp_make_link_relative(plugins_url('gtranslate/url_addon/gtranslate-email.php').'?glang='.$_SERVER['HTTP_X_GT_LANG']));
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($ch, CURLOPT_CAINFO, WP_PLUGIN_DIR . '/gtranslate/url_addon/cacert.pem');
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, array('body' => $rtwwpge_pdf_html, 'access_key' => md5(substr(NONCE_SALT, 0, 10) . substr(NONCE_KEY, 0, 5))));

        $response = curl_exec($ch);
        $response_info = curl_getinfo($ch);
        curl_close($ch);
        return $response;
	}
	
    function rtwwpge_add_new_elements()
	{
		require_once RTWWPGE_DIR.'/includes/elementor_pdf_generator.php';
	}

	function rtwwpge_json_envor()
	{
		ob_start();
	}
	
}
